pub struct AssistantService { /* private fields */ }assistant-service only.Expand description
Implements a client for the Discovery Engine API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
) -> anyhow::Result<()> {
let client = AssistantService::builder().build().await?;
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Service Description
Service for managing Assistant configuration and assisting users.
Configuration
To configure AssistantService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://discoveryengine.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
AssistantService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap AssistantService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl AssistantService
impl AssistantService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for AssistantService.
let client = AssistantService::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: AssistantService + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: AssistantService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &AssistantService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &AssistantService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &AssistantService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for AssistantService
impl Clone for AssistantService
Sourcefn clone(&self) -> AssistantService
fn clone(&self) -> AssistantService
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for AssistantService
impl !UnwindSafe for AssistantService
impl Freeze for AssistantService
impl Send for AssistantService
impl Sync for AssistantService
impl Unpin for AssistantService
impl UnsafeUnpin for AssistantService