pub struct ConversationalSearchService { /* private fields */ }conversational-search-service only.Expand description
Implements a client for the Discovery Engine API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = ConversationalSearchService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_conversations()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Service for conversational search.
Configuration
To configure ConversationalSearchService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://discoveryengine.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
ConversationalSearchService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap ConversationalSearchService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl ConversationalSearchService
impl ConversationalSearchService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for ConversationalSearchService.
let client = ConversationalSearchService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: ConversationalSearchService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: ConversationalSearchService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn converse_conversation(&self) -> ConverseConversation
pub fn converse_conversation(&self) -> ConverseConversation
Converses a conversation.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ConversationalSearchService
) -> Result<()> {
let response = client.converse_conversation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_conversation(&self) -> CreateConversation
pub fn create_conversation(&self) -> CreateConversation
Creates a Conversation.
If the Conversation to create already exists, an ALREADY_EXISTS error is returned.
Example
use google_cloud_discoveryengine_v1::model::Conversation;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ConversationalSearchService, parent: &str
) -> Result<()> {
let response = client.create_conversation()
.set_parent(parent)
.set_conversation(
Conversation::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_conversation(&self) -> DeleteConversation
pub fn delete_conversation(&self) -> DeleteConversation
Deletes a Conversation.
If the Conversation to delete does not exist, a NOT_FOUND error is returned.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ConversationalSearchService, name: &str
) -> Result<()> {
client.delete_conversation()
.set_name(name)
.send().await?;
Ok(())
}Sourcepub fn update_conversation(&self) -> UpdateConversation
pub fn update_conversation(&self) -> UpdateConversation
Updates a Conversation.
Conversation action type cannot be changed. If the Conversation to update does not exist, a NOT_FOUND error is returned.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_discoveryengine_v1::model::Conversation;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ConversationalSearchService, name: &str
) -> Result<()> {
let response = client.update_conversation()
.set_conversation(
Conversation::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_conversation(&self) -> GetConversation
pub fn get_conversation(&self) -> GetConversation
Gets a Conversation.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ConversationalSearchService, name: &str
) -> Result<()> {
let response = client.get_conversation()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_conversations(&self) -> ListConversations
pub fn list_conversations(&self) -> ListConversations
Lists all Conversations by their parent DataStore.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ConversationalSearchService, parent: &str
) -> Result<()> {
let mut list = client.list_conversations()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn answer_query(&self) -> AnswerQuery
pub fn answer_query(&self) -> AnswerQuery
Answer query method.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ConversationalSearchService
) -> Result<()> {
let response = client.answer_query()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_answer(&self) -> GetAnswer
pub fn get_answer(&self) -> GetAnswer
Gets a Answer.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ConversationalSearchService, name: &str
) -> Result<()> {
let response = client.get_answer()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_session(&self) -> CreateSession
pub fn create_session(&self) -> CreateSession
Creates a Session.
If the Session to create already exists, an ALREADY_EXISTS error is returned.
Example
use google_cloud_discoveryengine_v1::model::Session;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ConversationalSearchService, parent: &str
) -> Result<()> {
let response = client.create_session()
.set_parent(parent)
.set_session(
Session::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_session(&self) -> DeleteSession
pub fn delete_session(&self) -> DeleteSession
Sourcepub fn update_session(&self) -> UpdateSession
pub fn update_session(&self) -> UpdateSession
Updates a Session.
Session action type cannot be changed. If the Session to update does not exist, a NOT_FOUND error is returned.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_discoveryengine_v1::model::Session;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ConversationalSearchService, name: &str
) -> Result<()> {
let response = client.update_session()
.set_session(
Session::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_session(&self) -> GetSession
pub fn get_session(&self) -> GetSession
Gets a Session.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ConversationalSearchService, name: &str
) -> Result<()> {
let response = client.get_session()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_sessions(&self) -> ListSessions
pub fn list_sessions(&self) -> ListSessions
Lists all Sessions by their parent DataStore.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ConversationalSearchService, parent: &str
) -> Result<()> {
let mut list = client.list_sessions()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ConversationalSearchService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ConversationalSearchService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ConversationalSearchService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for ConversationalSearchService
impl Clone for ConversationalSearchService
Sourcefn clone(&self) -> ConversationalSearchService
fn clone(&self) -> ConversationalSearchService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more