pub struct ProjectService { /* private fields */ }project-service only.Expand description
Implements a client for the Discovery Engine API.
Example
use google_cloud_lro::Poller;
let client = ProjectService::builder().build().await?;
let response = client.provision_project()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);Service Description
Service for operations on the Project.
Configuration
To configure ProjectService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://discoveryengine.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
ProjectService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap ProjectService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl ProjectService
impl ProjectService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for ProjectService.
let client = ProjectService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: ProjectService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: ProjectService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn provision_project(&self) -> ProvisionProject
pub fn provision_project(&self) -> ProvisionProject
Provisions the project resource. During the process, related systems will get prepared and initialized.
Caller must read the Terms for data use, and optionally specify in request to provide consent to that service terms.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ProjectService
) -> Result<()> {
let response = client.provision_project()
/* set fields */
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ProjectService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ProjectService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ProjectService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for ProjectService
impl Clone for ProjectService
Sourcefn clone(&self) -> ProjectService
fn clone(&self) -> ProjectService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more