pub struct SchemaService { /* private fields */ }schema-service only.Expand description
Implements a client for the Discovery Engine API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = SchemaService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_schemas()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Service for managing Schemas.
Configuration
To configure SchemaService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://discoveryengine.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
SchemaService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap SchemaService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl SchemaService
impl SchemaService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for SchemaService.
let client = SchemaService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: SchemaService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: SchemaService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn get_schema(&self) -> GetSchema
pub fn get_schema(&self) -> GetSchema
Sourcepub fn list_schemas(&self) -> ListSchemas
pub fn list_schemas(&self) -> ListSchemas
Gets a list of Schemas.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &SchemaService, parent: &str
) -> Result<()> {
let mut list = client.list_schemas()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn create_schema(&self) -> CreateSchema
pub fn create_schema(&self) -> CreateSchema
Creates a Schema.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_discoveryengine_v1::model::Schema;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &SchemaService, parent: &str
) -> Result<()> {
let response = client.create_schema()
.set_parent(parent)
.set_schema_id("schema_id_value")
.set_schema(
Schema::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_schema(&self) -> UpdateSchema
pub fn update_schema(&self) -> UpdateSchema
Updates a Schema.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_discoveryengine_v1::model::Schema;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &SchemaService, name: &str
) -> Result<()> {
let response = client.update_schema()
.set_schema(
Schema::new().set_name(name)/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_schema(&self) -> DeleteSchema
pub fn delete_schema(&self) -> DeleteSchema
Deletes a Schema.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &SchemaService, name: &str
) -> Result<()> {
client.delete_schema()
.set_name(name)
.poller().until_done().await?;
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &SchemaService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &SchemaService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &SchemaService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for SchemaService
impl Clone for SchemaService
Sourcefn clone(&self) -> SchemaService
fn clone(&self) -> SchemaService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more