pub struct ServingConfigService { /* private fields */ }serving-config-service only.Expand description
Implements a client for the Discovery Engine API.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_discoveryengine_v1::model::ServingConfig;
let client = ServingConfigService::builder().build().await?;
let name = "name_value";
let response = client.update_serving_config()
.set_serving_config(
ServingConfig::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);Service Description
Service for operations related to ServingConfig.
Configuration
To configure ServingConfigService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://discoveryengine.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
ServingConfigService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap ServingConfigService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl ServingConfigService
impl ServingConfigService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for ServingConfigService.
let client = ServingConfigService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: ServingConfigService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: ServingConfigService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn update_serving_config(&self) -> UpdateServingConfig
pub fn update_serving_config(&self) -> UpdateServingConfig
Updates a ServingConfig.
Returns a NOT_FOUND error if the ServingConfig does not exist.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_discoveryengine_v1::model::ServingConfig;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ServingConfigService, name: &str
) -> Result<()> {
let response = client.update_serving_config()
.set_serving_config(
ServingConfig::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ServingConfigService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ServingConfigService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &ServingConfigService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for ServingConfigService
impl Clone for ServingConfigService
Sourcefn clone(&self) -> ServingConfigService
fn clone(&self) -> ServingConfigService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more