pub struct SessionService { /* private fields */ }session-service only.Expand description
Implements a client for the Discovery Engine API.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
let client = SessionService::builder().build().await?;
let parent = "parent_value";
let mut list = client.list_sessions()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}Service Description
Service for managing Sessions and Session-related resources.
Configuration
To configure SessionService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://discoveryengine.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
SessionService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap SessionService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl SessionService
impl SessionService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for SessionService.
let client = SessionService::builder().build().await?;Sourcepub fn from_stub<T>(stub: T) -> Selfwhere
T: SessionService + 'static,
pub fn from_stub<T>(stub: T) -> Selfwhere
T: SessionService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_session(&self) -> CreateSession
pub fn create_session(&self) -> CreateSession
Creates a Session.
If the Session to create already exists, an ALREADY_EXISTS error is returned.
Example
use google_cloud_discoveryengine_v1::model::Session;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &SessionService, parent: &str
) -> Result<()> {
let response = client.create_session()
.set_parent(parent)
.set_session(
Session::new()/* set fields */
)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_session(&self) -> DeleteSession
pub fn delete_session(&self) -> DeleteSession
Sourcepub fn update_session(&self) -> UpdateSession
pub fn update_session(&self) -> UpdateSession
Updates a Session.
Session action type cannot be changed. If the Session to update does not exist, a NOT_FOUND error is returned.
Example
use google_cloud_wkt::FieldMask;
use google_cloud_discoveryengine_v1::model::Session;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &SessionService, name: &str
) -> Result<()> {
let response = client.update_session()
.set_session(
Session::new().set_name(name)/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_session(&self) -> GetSession
pub fn get_session(&self) -> GetSession
Gets a Session.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &SessionService, name: &str
) -> Result<()> {
let response = client.get_session()
.set_name(name)
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_sessions(&self) -> ListSessions
pub fn list_sessions(&self) -> ListSessions
Lists all Sessions by their parent DataStore.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &SessionService, parent: &str
) -> Result<()> {
let mut list = client.list_sessions()
.set_parent(parent)
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &SessionService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &SessionService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_discoveryengine_v1::Result;
async fn sample(
client: &SessionService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for SessionService
impl Clone for SessionService
Sourcefn clone(&self) -> SessionService
fn clone(&self) -> SessionService
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more