Module model

Module model 

The messages and enums that are part of this client library.

Modules

answerconversational-search-service or session-service
Defines additional types related to Answer.
answer_query_requestconversational-search-service
Defines additional types related to AnswerQueryRequest.
assist_answerassistant-service or conversational-search-service or session-service
Defines additional types related to AssistAnswer.
assistant_contentassistant-service or conversational-search-service or session-service
Defines additional types related to AssistantContent.
assistant_grounded_contentassistant-service or conversational-search-service or session-service
Defines additional types related to AssistantGroundedContent.
batch_get_documents_metadata_requestdocument-service
Defines additional types related to BatchGetDocumentsMetadataRequest.
batch_get_documents_metadata_responsedocument-service
Defines additional types related to BatchGetDocumentsMetadataResponse.
batch_update_user_licenses_requestuser-license-service
Defines additional types related to BatchUpdateUserLicensesRequest.
big_query_sourcecompletion-service or document-service or user-event-service
Defines additional types related to BigQuerySource.
bigtable_optionsdocument-service
Defines additional types related to BigtableOptions.
check_grounding_responsegrounded-generation-service
Defines additional types related to CheckGroundingResponse.
chunkconversational-search-service or search-service
Defines additional types related to Chunk.
cmek_configcmek-config-service or data-store-service or identity-mapping-store-service
Defines additional types related to CmekConfig.
complete_query_responsecompletion-service
Defines additional types related to CompleteQueryResponse.
completion_suggestioncompletion-service
Defines additional types related to CompletionSuggestion.
conditioncontrol-service
Defines additional types related to Condition.
controlcontrol-service
Defines additional types related to Control.
conversationconversational-search-service
Defines additional types related to Conversation.
conversation_messageconversational-search-service
Defines additional types related to ConversationMessage.
create_data_store_requestdata-store-service
Defines additional types related to CreateDataStoreRequest.
create_identity_mapping_store_requestidentity-mapping-store-service
Defines additional types related to CreateIdentityMappingStoreRequest.
custom_tuning_modelsearch-tuning-service
Defines additional types related to CustomTuningModel.
data_storedata-store-service
Defines additional types related to DataStore.
documentconversational-search-service or document-service or recommendation-service or search-service
Defines additional types related to Document.
document_inforecommendation-service or user-event-service
Defines additional types related to DocumentInfo.
document_processing_configdata-store-service
Defines additional types related to DocumentProcessingConfig.
engineengine-service
Defines additional types related to Engine.
fetch_sitemaps_requestsite-search-engine-service
Defines additional types related to FetchSitemapsRequest.
fetch_sitemaps_responsesite-search-engine-service
Defines additional types related to FetchSitemapsResponse.
generate_grounded_content_requestgrounded-generation-service
Defines additional types related to GenerateGroundedContentRequest.
generate_grounded_content_responsegrounded-generation-service
Defines additional types related to GenerateGroundedContentResponse.
grounded_generation_contentgrounded-generation-service
Defines additional types related to GroundedGenerationContent.
identity_mapping_entryidentity-mapping-store-service
Defines additional types related to IdentityMappingEntry.
import_completion_suggestions_requestcompletion-service
Defines additional types related to ImportCompletionSuggestionsRequest.
import_documents_requestdocument-service
Defines additional types related to ImportDocumentsRequest.
import_error_configcompletion-service or document-service or search-tuning-service or user-event-service
Defines additional types related to ImportErrorConfig.
import_identity_mappings_requestidentity-mapping-store-service
Defines additional types related to ImportIdentityMappingsRequest.
import_suggestion_deny_list_entries_requestcompletion-service
Defines additional types related to ImportSuggestionDenyListEntriesRequest.
import_user_events_requestuser-event-service
Defines additional types related to ImportUserEventsRequest.
intervalassistant-service or conversational-search-service or search-service or serving-config-service
Defines additional types related to Interval.
natural_language_query_understanding_configdata-store-service
Defines additional types related to NaturalLanguageQueryUnderstandingConfig.
principalconversational-search-service or document-service or recommendation-service or search-service
Defines additional types related to Principal.
projectproject-service
Defines additional types related to Project.
purge_documents_requestdocument-service
Defines additional types related to PurgeDocumentsRequest.
purge_error_configdocument-service
Defines additional types related to PurgeErrorConfig.
purge_identity_mappings_requestidentity-mapping-store-service
Defines additional types related to PurgeIdentityMappingsRequest.
queryassistant-service or conversational-search-service or session-service
Defines additional types related to Query.
recommend_responserecommendation-service
Defines additional types related to RecommendResponse.
recrawl_uris_responsesite-search-engine-service
Defines additional types related to RecrawlUrisResponse.
safety_ratingconversational-search-service or session-service
Defines additional types related to SafetyRating.
schemadata-store-service or schema-service
Defines additional types related to Schema.
search_requestassistant-service or conversational-search-service or search-service or serving-config-service
Defines additional types related to SearchRequest.
search_responseconversational-search-service or search-service
Defines additional types related to SearchResponse.
serving_configserving-config-service
Defines additional types related to ServingConfig.
sessionconversational-search-service or session-service
Defines additional types related to Session.
site_verification_infosite-search-engine-service
Defines additional types related to SiteVerificationInfo.
sitemapsite-search-engine-service
Defines additional types related to Sitemap.
stream_assist_requestassistant-service
Defines additional types related to StreamAssistRequest.
stream_assist_responseassistant-service
Defines additional types related to StreamAssistResponse.
suggestion_deny_list_entrycompletion-service
Defines additional types related to SuggestionDenyListEntry.
target_sitesite-search-engine-service
Defines additional types related to TargetSite.
train_custom_model_requestsearch-tuning-service
Defines additional types related to TrainCustomModelRequest.
user_licenseuser-license-service
Defines additional types related to UserLicense.
workspace_configdata-store-service
Defines additional types related to WorkspaceConfig.

Structs

AdvancedSiteSearchConfigdata-store-service
Configuration data for advance site search.
AlloyDbSourcedocument-service
AlloyDB source import data from.
Answerconversational-search-service or session-service
Defines an answer.
AnswerQueryRequestconversational-search-service
Request message for ConversationalSearchService.AnswerQuery method.
AnswerQueryResponseconversational-search-service
Response message for ConversationalSearchService.AnswerQuery method.
AssistAnswerassistant-service or conversational-search-service or session-service
AssistAnswer resource, main part of [AssistResponse][google.cloud.discoveryengine.v1.AssistResponse].
AssistUserMetadataassistant-service
User metadata of the request.
Assistantassistant-service and cmek-config-service and completion-service and control-service and conversational-search-service and data-store-service and document-service and engine-service and grounded-generation-service and identity-mapping-store-service and project-service and rank-service and recommendation-service and schema-service and search-service and search-tuning-service and serving-config-service and session-service and site-search-engine-service and user-event-service and user-license-service
Discovery Engine Assistant resource.
AssistantContentassistant-service or conversational-search-service or session-service
Multi-modal content.
AssistantGroundedContentassistant-service or conversational-search-service or session-service
A piece of content and possibly its grounding information.
BatchCreateTargetSiteMetadatasite-search-engine-service
Metadata related to the progress of the SiteSearchEngineService.BatchCreateTargetSites operation. This will be returned by the google.longrunning.Operation.metadata field.
BatchCreateTargetSitesRequestsite-search-engine-service
Request message for SiteSearchEngineService.BatchCreateTargetSites method.
BatchCreateTargetSitesResponsesite-search-engine-service
Response message for SiteSearchEngineService.BatchCreateTargetSites method.
BatchGetDocumentsMetadataRequestdocument-service
Request message for DocumentService.BatchGetDocumentsMetadata method.
BatchGetDocumentsMetadataResponsedocument-service
Response message for DocumentService.BatchGetDocumentsMetadata method.
BatchUpdateUserLicensesMetadatauser-license-service
Metadata related to the progress of the UserLicenseService.BatchUpdateUserLicenses operation. This will be returned by the google.longrunning.Operation.metadata field.
BatchUpdateUserLicensesRequestuser-license-service
Request message for UserLicenseService.BatchUpdateUserLicenses method.
BatchUpdateUserLicensesResponseuser-license-service
Response message for UserLicenseService.BatchUpdateUserLicenses method.
BatchVerifyTargetSitesMetadatasite-search-engine-service
Metadata related to the progress of the SiteSearchEngineService.BatchVerifyTargetSites operation. This will be returned by the google.longrunning.Operation.metadata field.
BatchVerifyTargetSitesRequestsite-search-engine-service
Request message for SiteSearchEngineService.BatchVerifyTargetSites method.
BatchVerifyTargetSitesResponsesite-search-engine-service
Response message for SiteSearchEngineService.BatchVerifyTargetSites method.
BigQuerySourcecompletion-service or document-service or user-event-service
BigQuery source import data from.
BigtableOptionsdocument-service
The Bigtable Options object that contains information to support the import.
BigtableSourcedocument-service
The Cloud Bigtable source for importing data.
CheckGroundingRequestgrounded-generation-service
Request message for GroundedGenerationService.CheckGrounding method.
CheckGroundingResponsegrounded-generation-service
Response message for the GroundedGenerationService.CheckGrounding method.
CheckGroundingSpecgrounded-generation-service
Specification for the grounding check.
Chunkconversational-search-service or search-service
Chunk captures all raw metadata information of items to be recommended or searched in the chunk mode.
CloudSqlSourcedocument-service
Cloud SQL source import data from.
CmekConfigcmek-config-service or data-store-service or identity-mapping-store-service
Configurations used to enable CMEK data encryption with Cloud KMS keys.
CollectUserEventRequestuser-event-service
Request message for CollectUserEvent method.
CompleteQueryRequestcompletion-service
Request message for CompletionService.CompleteQuery method.
CompleteQueryResponsecompletion-service
Response message for CompletionService.CompleteQuery method.
CompletionInforecommendation-service or user-event-service
Detailed completion information including completion attribution token and clicked completion info.
CompletionSuggestioncompletion-service
Autocomplete suggestions that are imported from Customer.
Conditioncontrol-service
Defines circumstances to be checked before allowing a behavior
Controlcontrol-service
Defines a conditioned behavior to employ during serving. Must be attached to a ServingConfig to be considered at serving time. Permitted actions dependent on SolutionType.
Conversationconversational-search-service
External conversation proto definition.
ConversationContextconversational-search-service
Defines context of the conversation
ConversationMessageconversational-search-service
Defines a conversation message.
ConverseConversationRequestconversational-search-service
Request message for ConversationalSearchService.ConverseConversation method.
ConverseConversationResponseconversational-search-service
Response message for ConversationalSearchService.ConverseConversation method.
CreateControlRequestcontrol-service
Request for CreateControl method.
CreateConversationRequestconversational-search-service
Request for CreateConversation method.
CreateDataStoreMetadatadata-store-service
Metadata related to the progress of the DataStoreService.CreateDataStore operation. This will be returned by the google.longrunning.Operation.metadata field.
CreateDataStoreRequestdata-store-service
Request for DataStoreService.CreateDataStore method.
CreateDocumentRequestdocument-service
Request message for DocumentService.CreateDocument method.
CreateEngineMetadataengine-service
Metadata related to the progress of the EngineService.CreateEngine operation. This will be returned by the google.longrunning.Operation.metadata field.
CreateEngineRequestengine-service
Request for EngineService.CreateEngine method.
CreateIdentityMappingStoreRequestidentity-mapping-store-service
Request message for IdentityMappingStoreService.CreateIdentityMappingStore
CreateSchemaMetadataschema-service
Metadata for Create Schema LRO.
CreateSchemaRequestschema-service
Request message for SchemaService.CreateSchema method.
CreateSessionRequestconversational-search-service or session-service
Request for CreateSession method.
CreateSitemapMetadatasite-search-engine-service
Metadata related to the progress of the SiteSearchEngineService.CreateSitemap operation. This will be returned by the google.longrunning.Operation.metadata field.
CreateSitemapRequestsite-search-engine-service
Request message for SiteSearchEngineService.CreateSitemap method.
CreateTargetSiteMetadatasite-search-engine-service
Metadata related to the progress of the SiteSearchEngineService.CreateTargetSite operation. This will be returned by the google.longrunning.Operation.metadata field.
CreateTargetSiteRequestsite-search-engine-service
Request message for SiteSearchEngineService.CreateTargetSite method.
CustomAttributerecommendation-service or user-event-service
A custom attribute that is not explicitly modeled in a resource, e.g. UserEvent.
CustomTuningModelsearch-tuning-service
Metadata that describes a custom tuned model.
DataStoredata-store-service
DataStore captures global settings and configs at the DataStore level.
DeleteCmekConfigMetadatacmek-config-service
Metadata related to the progress of the CmekConfigService.DeleteCmekConfig operation. This will be returned by the google.longrunning.Operation.metadata field.
DeleteCmekConfigRequestcmek-config-service
Request message for CmekConfigService.DeleteCmekConfig method.
DeleteControlRequestcontrol-service
Request for DeleteControl method.
DeleteConversationRequestconversational-search-service
Request for DeleteConversation method.
DeleteDataStoreMetadatadata-store-service
Metadata related to the progress of the DataStoreService.DeleteDataStore operation. This will be returned by the google.longrunning.Operation.metadata field.
DeleteDataStoreRequestdata-store-service
Request message for DataStoreService.DeleteDataStore method.
DeleteDocumentRequestdocument-service
Request message for DocumentService.DeleteDocument method.
DeleteEngineMetadataengine-service
Metadata related to the progress of the EngineService.DeleteEngine operation. This will be returned by the google.longrunning.Operation.metadata field.
DeleteEngineRequestengine-service
Request message for EngineService.DeleteEngine method.
DeleteIdentityMappingStoreMetadataidentity-mapping-store-service
Metadata related to the progress of the IdentityMappingStoreService.DeleteIdentityMappingStore operation. This will be returned by the google.longrunning.Operation.metadata field.
DeleteIdentityMappingStoreRequestidentity-mapping-store-service
Request message for IdentityMappingStoreService.DeleteIdentityMappingStore
DeleteSchemaMetadataschema-service
Metadata for DeleteSchema LRO.
DeleteSchemaRequestschema-service
Request message for SchemaService.DeleteSchema method.
DeleteSessionRequestconversational-search-service or session-service
Request for DeleteSession method.
DeleteSitemapMetadatasite-search-engine-service
Metadata related to the progress of the SiteSearchEngineService.DeleteSitemap operation. This will be returned by the google.longrunning.Operation.metadata field.
DeleteSitemapRequestsite-search-engine-service
Request message for SiteSearchEngineService.DeleteSitemap method.
DeleteTargetSiteMetadatasite-search-engine-service
Metadata related to the progress of the SiteSearchEngineService.DeleteTargetSite operation. This will be returned by the google.longrunning.Operation.metadata field.
DeleteTargetSiteRequestsite-search-engine-service
Request message for SiteSearchEngineService.DeleteTargetSite method.
DisableAdvancedSiteSearchMetadatasite-search-engine-service
Metadata related to the progress of the SiteSearchEngineService.DisableAdvancedSiteSearch operation. This will be returned by the google.longrunning.Operation.metadata field.
DisableAdvancedSiteSearchRequestsite-search-engine-service
Request message for SiteSearchEngineService.DisableAdvancedSiteSearch method.
DisableAdvancedSiteSearchResponsesite-search-engine-service
Response message for SiteSearchEngineService.DisableAdvancedSiteSearch method.
Documentconversational-search-service or document-service or recommendation-service or search-service
Document captures all raw metadata information of items to be recommended or searched.
DocumentInforecommendation-service or user-event-service
Detailed document information associated with a user event.
DocumentProcessingConfigdata-store-service
A singleton resource of DataStore. If it’s empty when DataStore is created and DataStore is set to DataStore.ContentConfig.CONTENT_REQUIRED, the default parser will default to digital parser.
DoubleListconversational-search-service or search-service
Double list.
EnableAdvancedSiteSearchMetadatasite-search-engine-service
Metadata related to the progress of the SiteSearchEngineService.EnableAdvancedSiteSearch operation. This will be returned by the google.longrunning.Operation.metadata field.
EnableAdvancedSiteSearchRequestsite-search-engine-service
Request message for SiteSearchEngineService.EnableAdvancedSiteSearch method.
EnableAdvancedSiteSearchResponsesite-search-engine-service
Response message for SiteSearchEngineService.EnableAdvancedSiteSearch method.
Engineengine-service
Metadata that describes the training and serving parameters of an Engine.
FactChunkgrounded-generation-service
Fact Chunk.
FetchDomainVerificationStatusRequestsite-search-engine-service
Request message for SiteSearchEngineService.FetchDomainVerificationStatus method.
FetchDomainVerificationStatusResponsesite-search-engine-service
Response message for SiteSearchEngineService.FetchDomainVerificationStatus method.
FetchSitemapsRequestsite-search-engine-service
Request message for SiteSearchEngineService.FetchSitemaps method.
FetchSitemapsResponsesite-search-engine-service
Response message for SiteSearchEngineService.FetchSitemaps method.
FhirStoreSourcedocument-service
Cloud FhirStore source import data from.
FirestoreSourcedocument-service
Firestore source import data from.
GcsSourcecompletion-service or document-service or user-event-service
Cloud Storage location for input content.
GenerateGroundedContentRequestgrounded-generation-service
Top-level message sent by the client for the GenerateGroundedContent method.
GenerateGroundedContentResponsegrounded-generation-service
Response for the GenerateGroundedContent method.
GetAnswerRequestconversational-search-service
Request for GetAnswer method.
GetCmekConfigRequestcmek-config-service
Request message for GetCmekConfigRequest method.
GetControlRequestcontrol-service
Request for GetControl method.
GetConversationRequestconversational-search-service
Request for GetConversation method.
GetDataStoreRequestdata-store-service
Request message for DataStoreService.GetDataStore method.
GetDocumentRequestdocument-service
Request message for DocumentService.GetDocument method.
GetEngineRequestengine-service
Request message for EngineService.GetEngine method.
GetIdentityMappingStoreRequestidentity-mapping-store-service
Request message for IdentityMappingStoreService.GetIdentityMappingStore
GetSchemaRequestschema-service
Request message for SchemaService.GetSchema method.
GetSessionRequestconversational-search-service or session-service
Request for GetSession method.
GetSiteSearchEngineRequestsite-search-engine-service
Request message for SiteSearchEngineService.GetSiteSearchEngine method.
GetTargetSiteRequestsite-search-engine-service
Request message for SiteSearchEngineService.GetTargetSite method.
GroundedGenerationContentgrounded-generation-service
Base structured datatype containing multi-part content of a message.
GroundingFactgrounded-generation-service
Grounding Fact.
HealthcareFhirConfigdata-store-service
Config to data store for HEALTHCARE_FHIR vertical.
IdentityMappingEntryidentity-mapping-store-service
Identity Mapping Entry that maps an external identity to an internal identity.
IdentityMappingEntryOperationMetadataidentity-mapping-store-service
IdentityMappingEntry LongRunningOperation metadata for IdentityMappingStoreService.ImportIdentityMappings and IdentityMappingStoreService.PurgeIdentityMappings
IdentityMappingStoreidentity-mapping-store-service
Identity Mapping Store which contains Identity Mapping Entries.
ImportCompletionSuggestionsMetadatacompletion-service
Metadata related to the progress of the ImportCompletionSuggestions operation. This will be returned by the google.longrunning.Operation.metadata field.
ImportCompletionSuggestionsRequestcompletion-service
Request message for CompletionService.ImportCompletionSuggestions method.
ImportCompletionSuggestionsResponsecompletion-service
Response of the CompletionService.ImportCompletionSuggestions method. If the long running operation is done, this message is returned by the google.longrunning.Operations.response field if the operation is successful.
ImportDocumentsMetadatadocument-service
Metadata related to the progress of the ImportDocuments operation. This is returned by the google.longrunning.Operation.metadata field.
ImportDocumentsRequestdocument-service
Request message for Import methods.
ImportDocumentsResponsedocument-service
Response of the ImportDocumentsRequest. If the long running operation is done, then this message is returned by the google.longrunning.Operations.response field if the operation was successful.
ImportErrorConfigcompletion-service or document-service or search-tuning-service or user-event-service
Configuration of destination for Import related errors.
ImportIdentityMappingsRequestidentity-mapping-store-service
Request message for IdentityMappingStoreService.ImportIdentityMappings
ImportIdentityMappingsResponseidentity-mapping-store-service
Response message for IdentityMappingStoreService.ImportIdentityMappings
ImportSuggestionDenyListEntriesMetadatacompletion-service
Metadata related to the progress of the ImportSuggestionDenyListEntries operation. This is returned by the google.longrunning.Operation.metadata field.
ImportSuggestionDenyListEntriesRequestcompletion-service
Request message for CompletionService.ImportSuggestionDenyListEntries method.
ImportSuggestionDenyListEntriesResponsecompletion-service
Response message for CompletionService.ImportSuggestionDenyListEntries method.
ImportUserEventsMetadatauser-event-service
Metadata related to the progress of the Import operation. This is returned by the google.longrunning.Operation.metadata field.
ImportUserEventsRequestuser-event-service
Request message for the ImportUserEvents request.
ImportUserEventsResponseuser-event-service
Response of the ImportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations.response field if the operation was successful.
Intervalassistant-service or conversational-search-service or search-service or serving-config-service
A floating point interval.
ListCmekConfigsRequestcmek-config-service
Request message for CmekConfigService.ListCmekConfigs method.
ListCmekConfigsResponsecmek-config-service
Response message for CmekConfigService.ListCmekConfigs method.
ListControlsRequestcontrol-service
Request for ListControls method.
ListControlsResponsecontrol-service
Response for ListControls method.
ListConversationsRequestconversational-search-service
Request for ListConversations method.
ListConversationsResponseconversational-search-service
Response for ListConversations method.
ListCustomModelsRequestsearch-tuning-service
Request message for SearchTuningService.ListCustomModels method.
ListCustomModelsResponsesearch-tuning-service
Response message for SearchTuningService.ListCustomModels method.
ListDataStoresRequestdata-store-service
Request message for DataStoreService.ListDataStores method.
ListDataStoresResponsedata-store-service
Response message for DataStoreService.ListDataStores method.
ListDocumentsRequestdocument-service
Request message for DocumentService.ListDocuments method.
ListDocumentsResponsedocument-service
Response message for DocumentService.ListDocuments method.
ListEnginesRequestengine-service
Request message for EngineService.ListEngines method.
ListEnginesResponseengine-service
Response message for EngineService.ListEngines method.
ListIdentityMappingStoresRequestidentity-mapping-store-service
Request message for IdentityMappingStoreService.ListIdentityMappingStores
ListIdentityMappingStoresResponseidentity-mapping-store-service
Response message for IdentityMappingStoreService.ListIdentityMappingStores
ListIdentityMappingsRequestidentity-mapping-store-service
Request message for IdentityMappingStoreService.ListIdentityMappings
ListIdentityMappingsResponseidentity-mapping-store-service
Response message for IdentityMappingStoreService.ListIdentityMappings
ListSchemasRequestschema-service
Request message for SchemaService.ListSchemas method.
ListSchemasResponseschema-service
Response message for SchemaService.ListSchemas method.
ListSessionsRequestconversational-search-service or session-service
Request for ListSessions method.
ListSessionsResponseconversational-search-service or session-service
Response for ListSessions method.
ListTargetSitesRequestsite-search-engine-service
Request message for SiteSearchEngineService.ListTargetSites method.
ListTargetSitesResponsesite-search-engine-service
Response message for SiteSearchEngineService.ListTargetSites method.
ListUserLicensesRequestuser-license-service
Request message for UserLicenseService.ListUserLicenses.
ListUserLicensesResponseuser-license-service
Response message for UserLicenseService.ListUserLicenses.
MediaInforecommendation-service or user-event-service
Media-specific user event information.
NaturalLanguageQueryUnderstandingConfigdata-store-service
Configuration for Natural Language Query Understanding.
PageInforecommendation-service or user-event-service
Detailed page information.
PanelInforecommendation-service or user-event-service
Detailed panel information associated with a user event.
Principalconversational-search-service or document-service or recommendation-service or search-service
Principal identifier of a user or a group.
Projectproject-service
Metadata and configurations for a Google Cloud project in the service.
ProvisionProjectMetadataproject-service
Metadata associated with a project provision operation.
ProvisionProjectRequestproject-service
Request for ProjectService.ProvisionProject method.
PurgeCompletionSuggestionsMetadatacompletion-service
Metadata related to the progress of the PurgeCompletionSuggestions operation. This is returned by the google.longrunning.Operation.metadata field.
PurgeCompletionSuggestionsRequestcompletion-service
Request message for CompletionService.PurgeCompletionSuggestions method.
PurgeCompletionSuggestionsResponsecompletion-service
Response message for CompletionService.PurgeCompletionSuggestions method.
PurgeDocumentsMetadatadocument-service
Metadata related to the progress of the PurgeDocuments operation. This will be returned by the google.longrunning.Operation.metadata field.
PurgeDocumentsRequestdocument-service
Request message for DocumentService.PurgeDocuments method.
PurgeDocumentsResponsedocument-service
Response message for DocumentService.PurgeDocuments method. If the long running operation is successfully done, then this message is returned by the google.longrunning.Operations.response field.
PurgeErrorConfigdocument-service
Configuration of destination for Purge related errors.
PurgeIdentityMappingsRequestidentity-mapping-store-service
Request message for IdentityMappingStoreService.PurgeIdentityMappings
PurgeSuggestionDenyListEntriesMetadatacompletion-service
Metadata related to the progress of the PurgeSuggestionDenyListEntries operation. This is returned by the google.longrunning.Operation.metadata field.
PurgeSuggestionDenyListEntriesRequestcompletion-service
Request message for CompletionService.PurgeSuggestionDenyListEntries method.
PurgeSuggestionDenyListEntriesResponsecompletion-service
Response message for CompletionService.PurgeSuggestionDenyListEntries method.
PurgeUserEventsMetadatauser-event-service
Metadata related to the progress of the PurgeUserEvents operation. This will be returned by the google.longrunning.Operation.metadata field.
PurgeUserEventsRequestuser-event-service
Request message for PurgeUserEvents method.
PurgeUserEventsResponseuser-event-service
Response of the PurgeUserEventsRequest. If the long running operation is successfully done, then this message is returned by the google.longrunning.Operations.response field.
Queryassistant-service or conversational-search-service or session-service
Defines a user inputed query.
RankRequestrank-service
Request message for RankService.Rank method.
RankResponserank-service
Response message for RankService.Rank method.
RankingRecordrank-service
Record message for RankService.Rank method.
RecommendRequestrecommendation-service
Request message for Recommend method.
RecommendResponserecommendation-service
Response message for Recommend method.
RecrawlUrisMetadatasite-search-engine-service
Metadata related to the progress of the SiteSearchEngineService.RecrawlUris operation. This will be returned by the google.longrunning.Operation.metadata field.
RecrawlUrisRequestsite-search-engine-service
Request message for SiteSearchEngineService.RecrawlUris method.
RecrawlUrisResponsesite-search-engine-service
Response message for SiteSearchEngineService.RecrawlUris method.
Replyconversational-search-service
Defines a reply message to user.
SafetyRatingconversational-search-service or session-service
Safety rating corresponding to the generated content.
Schemadata-store-service or schema-service
Defines the structure and layout of a type of document data.
SearchInforecommendation-service or user-event-service
Detailed search information.
SearchLinkPromotioncontrol-service or conversational-search-service or search-service
Promotion proto includes uri and other helping information to display the promotion.
SearchRequestassistant-service or conversational-search-service or search-service or serving-config-service
Request message for SearchService.Search method.
SearchResponseconversational-search-service or search-service
Response message for SearchService.Search method.
ServingConfigserving-config-service
Configures metadata that is used to generate serving time results (e.g. search results or recommendation predictions). The ServingConfig is passed in the search and predict request and generates results.
Sessionconversational-search-service or session-service
External session proto definition.
SingleRegionKeycmek-config-service or data-store-service or identity-mapping-store-service
Metadata for single-regional CMEKs.
SiteSearchEnginesite-search-engine-service
SiteSearchEngine captures DataStore level site search persisting configurations. It is a singleton value per data store.
SiteVerificationInfosite-search-engine-service
Verification information for target sites in advanced site search.
Sitemapsite-search-engine-service
A sitemap for the SiteSearchEngine.
SpannerSourcedocument-service
The Spanner source for importing data
StreamAssistRequestassistant-service
Request for the [AssistantService.StreamAssist][google.cloud.discoveryengine.v1.AssistantService.StreamAssist] method.
StreamAssistResponseassistant-service
Response for the [AssistantService.StreamAssist][google.cloud.discoveryengine.v1.AssistantService.StreamAssist] method.
SuggestionDenyListEntrycompletion-service
Suggestion deny list entry identifying the phrase to block from suggestions and the applied operation for the phrase.
TargetSitesite-search-engine-service
A target site for the SiteSearchEngine.
TextInputconversational-search-service
Defines text input.
TrainCustomModelMetadatasearch-tuning-service
Metadata related to the progress of the TrainCustomModel operation. This is returned by the google.longrunning.Operation.metadata field.
TrainCustomModelRequestsearch-tuning-service
Request message for SearchTuningService.TrainCustomModel method.
TrainCustomModelResponsesearch-tuning-service
Response of the TrainCustomModelRequest. This message is returned by the google.longrunning.Operations.response field.
TransactionInforecommendation-service or user-event-service
A transaction represents the entire purchase transaction.
UpdateCmekConfigMetadatacmek-config-service
Metadata related to the progress of the CmekConfigService.UpdateCmekConfig operation. This will be returned by the google.longrunning.Operation.metadata field.
UpdateCmekConfigRequestcmek-config-service
Request message for UpdateCmekConfig method. rpc.
UpdateControlRequestcontrol-service
Request for UpdateControl method.
UpdateConversationRequestconversational-search-service
Request for UpdateConversation method.
UpdateDataStoreRequestdata-store-service
Request message for DataStoreService.UpdateDataStore method.
UpdateDocumentRequestdocument-service
Request message for DocumentService.UpdateDocument method.
UpdateEngineRequestengine-service
Request message for EngineService.UpdateEngine method.
UpdateSchemaMetadataschema-service
Metadata for UpdateSchema LRO.
UpdateSchemaRequestschema-service
Request message for SchemaService.UpdateSchema method.
UpdateServingConfigRequestserving-config-service
Request for UpdateServingConfig method.
UpdateSessionRequestconversational-search-service or session-service
Request for UpdateSession method.
UpdateTargetSiteMetadatasite-search-engine-service
Metadata related to the progress of the SiteSearchEngineService.UpdateTargetSite operation. This will be returned by the google.longrunning.Operation.metadata field.
UpdateTargetSiteRequestsite-search-engine-service
Request message for SiteSearchEngineService.UpdateTargetSite method.
UserEventrecommendation-service or user-event-service
UserEvent captures all metadata information Discovery Engine API needs to know about how end users interact with your website.
UserInfoassistant-service or conversational-search-service or recommendation-service or search-service or serving-config-service or user-event-service
Information of an end user.
UserLicenseuser-license-service
User License information assigned by the admin.
WorkspaceConfigdata-store-service
Config to store data store type configuration for workspace data
WriteUserEventRequestuser-event-service
Request message for WriteUserEvent method.

Enums

HarmCategoryconversational-search-service or session-service
Harm categories that will block the content.
IndustryVerticaldata-store-service or engine-service
The industry vertical associated with the DataStore.
SearchAddOnengine-service
Add-on that provides additional functionality for search.
SearchTierengine-service
Tiers of search features. Different tiers might have different pricing. To learn more, check the pricing documentation.
SearchUseCasecontrol-service
Defines a further subdivision of SolutionType. Specifically applies to SOLUTION_TYPE_SEARCH.
SolutionTypecontrol-service or data-store-service or engine-service or serving-config-service
The type of solution.