#[non_exhaustive]pub enum State {
Unspecified,
Creating,
Active,
KeyIssue,
Deleting,
DeleteFailed,
Unusable,
ActiveRotating,
Deleted,
UnknownValue(UnknownValue),
}cmek-config-service or data-store-service or identity-mapping-store-service only.Expand description
States of the CmekConfig.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The CmekConfig state is unknown.
Creating
The CmekConfig is creating.
Active
The CmekConfig can be used with DataStores.
KeyIssue
The CmekConfig is unavailable, most likely due to the KMS Key being revoked.
Deleting
The CmekConfig is deleting.
DeleteFailed
The CmekConfig deletion process failed.
Unusable
The CmekConfig is not usable, most likely due to some internal issue.
ActiveRotating
The KMS key version is being rotated.
Deleted
The KMS key is soft deleted. Some cleanup policy will eventually be applied.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations