#[non_exhaustive]pub enum BoostSpec {
FixedBoost(f32),
InterpolationBoostSpec(Box<InterpolationBoostSpec>),
}Available on crate feature
control-service only.Expand description
Constant value boost or custom ranking based boost specifications.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FixedBoost(f32)
Optional. Strength of the boost, which should be in [-1, 1]. Negative boost means demotion. Default is 0.0 (No-op).
InterpolationBoostSpec(Box<InterpolationBoostSpec>)
Optional. Complex specification for custom ranking based on customer defined attribute value.