#[non_exhaustive]pub struct ParsingConfig {
pub type_dedicated_config: Option<TypeDedicatedConfig>,
/* private fields */
}data-store-service only.Expand description
Related configurations applied to a specific type of document parser.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type_dedicated_config: Option<TypeDedicatedConfig>Configs for document processing types.
Implementations
Sourceimpl ParsingConfig
impl ParsingConfig
Sourcepub fn set_type_dedicated_config<T: Into<Option<TypeDedicatedConfig>>>(
self,
v: T,
) -> Self
pub fn set_type_dedicated_config<T: Into<Option<TypeDedicatedConfig>>>( self, v: T, ) -> Self
Sets the value of type_dedicated_config.
Note that all the setters affecting type_dedicated_config are mutually
exclusive.
Example
use google_cloud_discoveryengine_v1::model::document_processing_config::parsing_config::DigitalParsingConfig;
let x = ParsingConfig::new().set_type_dedicated_config(Some(
google_cloud_discoveryengine_v1::model::document_processing_config::parsing_config::TypeDedicatedConfig::DigitalParsingConfig(DigitalParsingConfig::default().into())));Sourcepub fn digital_parsing_config(&self) -> Option<&Box<DigitalParsingConfig>>
pub fn digital_parsing_config(&self) -> Option<&Box<DigitalParsingConfig>>
The value of type_dedicated_config
if it holds a DigitalParsingConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_digital_parsing_config<T: Into<Box<DigitalParsingConfig>>>(
self,
v: T,
) -> Self
pub fn set_digital_parsing_config<T: Into<Box<DigitalParsingConfig>>>( self, v: T, ) -> Self
Sets the value of type_dedicated_config
to hold a DigitalParsingConfig.
Note that all the setters affecting type_dedicated_config are
mutually exclusive.
Example
use google_cloud_discoveryengine_v1::model::document_processing_config::parsing_config::DigitalParsingConfig;
let x = ParsingConfig::new().set_digital_parsing_config(DigitalParsingConfig::default()/* use setters */);
assert!(x.digital_parsing_config().is_some());
assert!(x.ocr_parsing_config().is_none());
assert!(x.layout_parsing_config().is_none());Sourcepub fn ocr_parsing_config(&self) -> Option<&Box<OcrParsingConfig>>
pub fn ocr_parsing_config(&self) -> Option<&Box<OcrParsingConfig>>
The value of type_dedicated_config
if it holds a OcrParsingConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_ocr_parsing_config<T: Into<Box<OcrParsingConfig>>>(
self,
v: T,
) -> Self
pub fn set_ocr_parsing_config<T: Into<Box<OcrParsingConfig>>>( self, v: T, ) -> Self
Sets the value of type_dedicated_config
to hold a OcrParsingConfig.
Note that all the setters affecting type_dedicated_config are
mutually exclusive.
Example
use google_cloud_discoveryengine_v1::model::document_processing_config::parsing_config::OcrParsingConfig;
let x = ParsingConfig::new().set_ocr_parsing_config(OcrParsingConfig::default()/* use setters */);
assert!(x.ocr_parsing_config().is_some());
assert!(x.digital_parsing_config().is_none());
assert!(x.layout_parsing_config().is_none());Sourcepub fn layout_parsing_config(&self) -> Option<&Box<LayoutParsingConfig>>
pub fn layout_parsing_config(&self) -> Option<&Box<LayoutParsingConfig>>
The value of type_dedicated_config
if it holds a LayoutParsingConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_layout_parsing_config<T: Into<Box<LayoutParsingConfig>>>(
self,
v: T,
) -> Self
pub fn set_layout_parsing_config<T: Into<Box<LayoutParsingConfig>>>( self, v: T, ) -> Self
Sets the value of type_dedicated_config
to hold a LayoutParsingConfig.
Note that all the setters affecting type_dedicated_config are
mutually exclusive.
Example
use google_cloud_discoveryengine_v1::model::document_processing_config::parsing_config::LayoutParsingConfig;
let x = ParsingConfig::new().set_layout_parsing_config(LayoutParsingConfig::default()/* use setters */);
assert!(x.layout_parsing_config().is_some());
assert!(x.digital_parsing_config().is_none());
assert!(x.ocr_parsing_config().is_none());Trait Implementations
Sourceimpl Clone for ParsingConfig
impl Clone for ParsingConfig
Sourcefn clone(&self) -> ParsingConfig
fn clone(&self) -> ParsingConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ParsingConfig
impl Debug for ParsingConfig
Sourceimpl Default for ParsingConfig
impl Default for ParsingConfig
Sourcefn default() -> ParsingConfig
fn default() -> ParsingConfig
Sourceimpl Message for ParsingConfig
impl Message for ParsingConfig
Sourceimpl PartialEq for ParsingConfig
impl PartialEq for ParsingConfig
impl StructuralPartialEq for ParsingConfig