#[non_exhaustive]pub struct AgentCreationConfig {
pub business: String,
pub default_language_code: String,
pub time_zone: String,
pub location: String,
/* private fields */
}engine-service only.Expand description
Configurations for generating a Dialogflow agent.
Note that these configurations are one-time consumed by and passed to Dialogflow service. It means they cannot be retrieved using EngineService.GetEngine or EngineService.ListEngines API after engine creation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.business: StringName of the company, organization or other entity that the agent represents. Used for knowledge connector LLM prompt and for knowledge search.
default_language_code: StringRequired. The default language of the agent as a language tag. See Language Support for a list of the currently supported language codes.
time_zone: StringRequired. The time zone of the agent from the time zone database, e.g., America/New_York, Europe/Paris.
location: StringAgent location for Agent creation, supported values: global/us/eu. If not provided, us Engine will create Agent using us-central-1 by default; eu Engine will create Agent using eu-west-1 by default.
Implementations
Sourceimpl AgentCreationConfig
impl AgentCreationConfig
Sourcepub fn set_business<T: Into<String>>(self, v: T) -> Self
pub fn set_business<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_default_language_code<T: Into<String>>(self, v: T) -> Self
pub fn set_default_language_code<T: Into<String>>(self, v: T) -> Self
Sets the value of default_language_code.
Example
let x = AgentCreationConfig::new().set_default_language_code("example");Sourcepub fn set_time_zone<T: Into<String>>(self, v: T) -> Self
pub fn set_time_zone<T: Into<String>>(self, v: T) -> Self