#[non_exhaustive]pub struct EngineFeaturesConfig {
pub type_dedicated_config: Option<TypeDedicatedConfig>,
/* private fields */
}engine-service only.Expand description
More feature configs of the selected engine type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type_dedicated_config: Option<TypeDedicatedConfig>Feature related configurations applied to a specific type of meida recommendation engines.
Implementations
Sourceimpl EngineFeaturesConfig
impl EngineFeaturesConfig
Sourcepub fn set_type_dedicated_config<T: Into<Option<TypeDedicatedConfig>>>(
self,
v: T,
) -> Self
pub fn set_type_dedicated_config<T: Into<Option<TypeDedicatedConfig>>>( self, v: T, ) -> Self
Sets the value of type_dedicated_config.
Note that all the setters affecting type_dedicated_config are mutually
exclusive.
Example
use google_cloud_discoveryengine_v1::model::engine::media_recommendation_engine_config::RecommendedForYouFeatureConfig;
let x = EngineFeaturesConfig::new().set_type_dedicated_config(Some(
google_cloud_discoveryengine_v1::model::engine::media_recommendation_engine_config::engine_features_config::TypeDedicatedConfig::RecommendedForYouConfig(RecommendedForYouFeatureConfig::default().into())));Sourcepub fn recommended_for_you_config(
&self,
) -> Option<&Box<RecommendedForYouFeatureConfig>>
pub fn recommended_for_you_config( &self, ) -> Option<&Box<RecommendedForYouFeatureConfig>>
The value of type_dedicated_config
if it holds a RecommendedForYouConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_recommended_for_you_config<T: Into<Box<RecommendedForYouFeatureConfig>>>(
self,
v: T,
) -> Self
pub fn set_recommended_for_you_config<T: Into<Box<RecommendedForYouFeatureConfig>>>( self, v: T, ) -> Self
Sets the value of type_dedicated_config
to hold a RecommendedForYouConfig.
Note that all the setters affecting type_dedicated_config are
mutually exclusive.
Example
use google_cloud_discoveryengine_v1::model::engine::media_recommendation_engine_config::RecommendedForYouFeatureConfig;
let x = EngineFeaturesConfig::new().set_recommended_for_you_config(RecommendedForYouFeatureConfig::default()/* use setters */);
assert!(x.recommended_for_you_config().is_some());
assert!(x.most_popular_config().is_none());Sourcepub fn most_popular_config(&self) -> Option<&Box<MostPopularFeatureConfig>>
pub fn most_popular_config(&self) -> Option<&Box<MostPopularFeatureConfig>>
The value of type_dedicated_config
if it holds a MostPopularConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_most_popular_config<T: Into<Box<MostPopularFeatureConfig>>>(
self,
v: T,
) -> Self
pub fn set_most_popular_config<T: Into<Box<MostPopularFeatureConfig>>>( self, v: T, ) -> Self
Sets the value of type_dedicated_config
to hold a MostPopularConfig.
Note that all the setters affecting type_dedicated_config are
mutually exclusive.
Example
use google_cloud_discoveryengine_v1::model::engine::media_recommendation_engine_config::MostPopularFeatureConfig;
let x = EngineFeaturesConfig::new().set_most_popular_config(MostPopularFeatureConfig::default()/* use setters */);
assert!(x.most_popular_config().is_some());
assert!(x.recommended_for_you_config().is_none());Trait Implementations
Sourceimpl Clone for EngineFeaturesConfig
impl Clone for EngineFeaturesConfig
Sourcefn clone(&self) -> EngineFeaturesConfig
fn clone(&self) -> EngineFeaturesConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for EngineFeaturesConfig
impl Debug for EngineFeaturesConfig
Sourceimpl Default for EngineFeaturesConfig
impl Default for EngineFeaturesConfig
Sourcefn default() -> EngineFeaturesConfig
fn default() -> EngineFeaturesConfig
Sourceimpl Message for EngineFeaturesConfig
impl Message for EngineFeaturesConfig
Sourceimpl PartialEq for EngineFeaturesConfig
impl PartialEq for EngineFeaturesConfig
impl StructuralPartialEq for EngineFeaturesConfig