#[non_exhaustive]pub struct RecommendedForYouFeatureConfig {
pub context_event_type: String,
/* private fields */
}Available on crate feature
engine-service only.Expand description
Additional feature configurations for creating a recommended-for-you
engine.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.context_event_type: StringThe type of event with which the engine is queried at prediction time.
If set to generic, only view-item, media-play,and
media-complete will be used as context-event in engine training. If
set to view-home-page, view-home-page will also be used as
context-events in addition to view-item, media-play, and
media-complete. Currently supported for the recommended-for-you
engine. Currently supported values: view-home-page, generic.
Implementations
Sourceimpl RecommendedForYouFeatureConfig
impl RecommendedForYouFeatureConfig
Sourcepub fn set_context_event_type<T: Into<String>>(self, v: T) -> Self
pub fn set_context_event_type<T: Into<String>>(self, v: T) -> Self
Sets the value of context_event_type.
Example
ⓘ
let x = RecommendedForYouFeatureConfig::new().set_context_event_type("example");Trait Implementations
Sourceimpl Clone for RecommendedForYouFeatureConfig
impl Clone for RecommendedForYouFeatureConfig
Sourcefn clone(&self) -> RecommendedForYouFeatureConfig
fn clone(&self) -> RecommendedForYouFeatureConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for RecommendedForYouFeatureConfig
impl Default for RecommendedForYouFeatureConfig
Sourcefn default() -> RecommendedForYouFeatureConfig
fn default() -> RecommendedForYouFeatureConfig
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for RecommendedForYouFeatureConfig
impl PartialEq for RecommendedForYouFeatureConfig
Sourcefn eq(&self, other: &RecommendedForYouFeatureConfig) -> bool
fn eq(&self, other: &RecommendedForYouFeatureConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RecommendedForYouFeatureConfig