#[non_exhaustive]pub enum SolutionType {
Unspecified,
Recommendation,
Search,
Chat,
GenerativeChat,
UnknownValue(UnknownValue),
}control-service or data-store-service or engine-service or serving-config-service only.Expand description
The type of solution.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default value.
Recommendation
Used for Recommendations AI.
Search
Used for Discovery Search.
Chat
Used for use cases related to the Generative AI agent.
GenerativeChat
Used for use cases related to the Generative Chat agent.
It’s used for Generative chat engine only, the associated data stores
must enrolled with SOLUTION_TYPE_CHAT solution.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using SolutionType::value or SolutionType::name.
Implementations