Module interval

Module interval 

Available on crate features assistant-service or conversational-search-service or search-service or serving-config-service only.
Defines additional types related to Interval.

Enums

Max
The upper bound of the interval. If neither of the max fields are set, then the upper bound is positive infinity.
Min
The lower bound of the interval. If neither of the min fields are set, then the lower bound is negative infinity.