#[non_exhaustive]pub enum Mode {
Unspecified,
DropCrowdedResults,
DemoteCrowdedResultsToEnd,
UnknownValue(UnknownValue),
}assistant-service or conversational-search-service or search-service or serving-config-service only.Expand description
Enum describing the mode to use for documents that are crowded away. They can be dropped or demoted to the later pages.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified crowding mode. In this case, server behavior defaults to Mode.DROP_CROWDED_RESULTS.
DropCrowdedResults
Drop crowded results.
DemoteCrowdedResultsToEnd
Demote crowded results to the later pages.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Mode::value or Mode::name.
Implementations