#[non_exhaustive]pub enum RankingExpressionBackend {
Unspecified,
Byoe,
Clearbox,
RankByEmbedding,
RankByFormula,
UnknownValue(UnknownValue),
}assistant-service or conversational-search-service or search-service or serving-config-service only.Expand description
The backend to use for the ranking expression evaluation.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default option for unspecified/unknown values.
Byoe
Deprecated: Use RANK_BY_EMBEDDING instead.
Ranking by custom embedding model, the default way to evaluate the
ranking expression. Legacy enum option, RANK_BY_EMBEDDING should be
used instead.
Clearbox
Deprecated: Use RANK_BY_FORMULA instead.
Ranking by custom formula. Legacy enum option, RANK_BY_FORMULA should
be used instead.
RankByEmbedding
Ranking by custom embedding model, the default way to evaluate the ranking expression.
RankByFormula
Ranking by custom formula.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using RankingExpressionBackend::value or RankingExpressionBackend::name.
Implementations