CrowdingSpec

Struct CrowdingSpec 

#[non_exhaustive]
pub struct CrowdingSpec { pub field: String, pub max_count: i32, pub mode: Mode, /* private fields */ }
Available on crate features assistant-service or conversational-search-service or search-service or serving-config-service only.
Specification for crowding. Crowding improves the diversity of search results by limiting the number of results that share the same field value. For example, crowding on the color field with a max_count of 3 and mode DROP_CROWDED_RESULTS will return at most 3 results with the same color across all pages.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
field: String

The field to use for crowding. Documents can be crowded by a field in the Document object. Crowding field is case sensitive.

max_count: i32

The maximum number of documents to keep per value of the field. Once there are at least max_count previous results which contain the same value for the given field (according to the order specified in order_by), later results with the same value are “crowded away”. If not specified, the default value is 1.

mode: Mode

Mode to use for documents that are crowded away.

Implementations

Source

impl CrowdingSpec

pub fn new() -> Self

pub fn set_field<T: Into<String>>(self, v: T) -> Self

Sets the value of field.

Example
let x = CrowdingSpec::new().set_field("example");
pub fn set_max_count<T: Into<i32>>(self, v: T) -> Self

Sets the value of max_count.

Example
let x = CrowdingSpec::new().set_max_count(42);
pub fn set_mode<T: Into<Mode>>(self, v: T) -> Self

Sets the value of mode.

Example
use google_cloud_discoveryengine_v1::model::search_request::crowding_spec::Mode;
let x0 = CrowdingSpec::new().set_mode(Mode::DropCrowdedResults);
let x1 = CrowdingSpec::new().set_mode(Mode::DemoteCrowdedResultsToEnd);