#[non_exhaustive]pub struct AnswerQueryRequest {Show 13 fields
pub serving_config: String,
pub query: Option<Query>,
pub session: String,
pub safety_spec: Option<SafetySpec>,
pub related_questions_spec: Option<RelatedQuestionsSpec>,
pub grounding_spec: Option<GroundingSpec>,
pub answer_generation_spec: Option<AnswerGenerationSpec>,
pub search_spec: Option<SearchSpec>,
pub query_understanding_spec: Option<QueryUnderstandingSpec>,
pub asynchronous_mode: bool,
pub user_pseudo_id: String,
pub user_labels: HashMap<String, String>,
pub end_user_spec: Option<EndUserSpec>,
/* private fields */
}conversational-search-service only.Expand description
Request message for ConversationalSearchService.AnswerQuery method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.serving_config: StringRequired. The resource name of the Search serving config, such as
projects/*/locations/global/collections/default_collection/engines/*/servingConfigs/default_serving_config,
or
projects/*/locations/global/collections/default_collection/dataStores/*/servingConfigs/default_serving_config.
This field is used to identify the serving configuration name, set
of models used to make the search.
query: Option<Query>Required. Current user query.
session: StringThe session resource name. Not required.
When session field is not set, the API is in sessionless mode.
We support auto session mode: users can use the wildcard symbol - as
session ID. A new ID will be automatically generated and assigned.
safety_spec: Option<SafetySpec>Model specification.
Related questions specification.
grounding_spec: Option<GroundingSpec>Optional. Grounding specification.
answer_generation_spec: Option<AnswerGenerationSpec>Answer generation specification.
search_spec: Option<SearchSpec>Search specification.
query_understanding_spec: Option<QueryUnderstandingSpec>Query understanding specification.
asynchronous_mode: boolDeprecated: This field is deprecated. Streaming Answer API will be supported.
Asynchronous mode control.
If enabled, the response will be returned with answer/session resource name without final answer. The API users need to do the polling to get the latest status of answer/session by calling ConversationalSearchService.GetAnswer or ConversationalSearchService.GetSession method.
user_pseudo_id: StringA unique identifier for tracking visitors. For example, this could be implemented with an HTTP cookie, which should be able to uniquely identify a visitor on a single device. This unique identifier should not change if the visitor logs in or out of the website.
This field should NOT have a fixed value such as unknown_visitor.
The field must be a UTF-8 encoded string with a length limit of 128
characters. Otherwise, an INVALID_ARGUMENT error is returned.
user_labels: HashMap<String, String>The user labels applied to a resource must meet the following requirements:
- Each resource can have multiple labels, up to a maximum of 64.
- Each label must be a key-value pair.
- Keys have a minimum length of 1 character and a maximum length of 63 characters and cannot be empty. Values can be empty and have a maximum length of 63 characters.
- Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. All characters must use UTF-8 encoding, and international characters are allowed.
- The key portion of a label must be unique. However, you can use the same key with multiple resources.
- Keys must start with a lowercase letter or international character.
See Google Cloud Document for more details.
end_user_spec: Option<EndUserSpec>Optional. End user specification.
Implementations
Sourceimpl AnswerQueryRequest
impl AnswerQueryRequest
Sourcepub fn set_serving_config<T: Into<String>>(self, v: T) -> Self
pub fn set_serving_config<T: Into<String>>(self, v: T) -> Self
Sets the value of serving_config.
Example
let x = AnswerQueryRequest::new().set_serving_config(format!("projects/{project_id}/locations/{location_id}/dataStores/{data_store_id}/servingConfigs/{serving_config_id}"));Sourcepub fn set_or_clear_query<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_query<T>(self, v: Option<T>) -> Self
Sourcepub fn set_session<T: Into<String>>(self, v: T) -> Self
pub fn set_session<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_safety_spec<T>(self, v: T) -> Selfwhere
T: Into<SafetySpec>,
pub fn set_safety_spec<T>(self, v: T) -> Selfwhere
T: Into<SafetySpec>,
Sets the value of safety_spec.
Example
use google_cloud_discoveryengine_v1::model::answer_query_request::SafetySpec;
let x = AnswerQueryRequest::new().set_safety_spec(SafetySpec::default()/* use setters */);Sourcepub fn set_or_clear_safety_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<SafetySpec>,
pub fn set_or_clear_safety_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<SafetySpec>,
Sets or clears the value of safety_spec.
Example
use google_cloud_discoveryengine_v1::model::answer_query_request::SafetySpec;
let x = AnswerQueryRequest::new().set_or_clear_safety_spec(Some(SafetySpec::default()/* use setters */));
let x = AnswerQueryRequest::new().set_or_clear_safety_spec(None::<SafetySpec>);Sets the value of related_questions_spec.
Example
use google_cloud_discoveryengine_v1::model::answer_query_request::RelatedQuestionsSpec;
let x = AnswerQueryRequest::new().set_related_questions_spec(RelatedQuestionsSpec::default()/* use setters */);Sets or clears the value of related_questions_spec.
Example
use google_cloud_discoveryengine_v1::model::answer_query_request::RelatedQuestionsSpec;
let x = AnswerQueryRequest::new().set_or_clear_related_questions_spec(Some(RelatedQuestionsSpec::default()/* use setters */));
let x = AnswerQueryRequest::new().set_or_clear_related_questions_spec(None::<RelatedQuestionsSpec>);Sourcepub fn set_grounding_spec<T>(self, v: T) -> Selfwhere
T: Into<GroundingSpec>,
pub fn set_grounding_spec<T>(self, v: T) -> Selfwhere
T: Into<GroundingSpec>,
Sets the value of grounding_spec.
Example
use google_cloud_discoveryengine_v1::model::answer_query_request::GroundingSpec;
let x = AnswerQueryRequest::new().set_grounding_spec(GroundingSpec::default()/* use setters */);Sourcepub fn set_or_clear_grounding_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<GroundingSpec>,
pub fn set_or_clear_grounding_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<GroundingSpec>,
Sets or clears the value of grounding_spec.
Example
use google_cloud_discoveryengine_v1::model::answer_query_request::GroundingSpec;
let x = AnswerQueryRequest::new().set_or_clear_grounding_spec(Some(GroundingSpec::default()/* use setters */));
let x = AnswerQueryRequest::new().set_or_clear_grounding_spec(None::<GroundingSpec>);Sourcepub fn set_answer_generation_spec<T>(self, v: T) -> Selfwhere
T: Into<AnswerGenerationSpec>,
pub fn set_answer_generation_spec<T>(self, v: T) -> Selfwhere
T: Into<AnswerGenerationSpec>,
Sets the value of answer_generation_spec.
Example
use google_cloud_discoveryengine_v1::model::answer_query_request::AnswerGenerationSpec;
let x = AnswerQueryRequest::new().set_answer_generation_spec(AnswerGenerationSpec::default()/* use setters */);Sourcepub fn set_or_clear_answer_generation_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<AnswerGenerationSpec>,
pub fn set_or_clear_answer_generation_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<AnswerGenerationSpec>,
Sets or clears the value of answer_generation_spec.
Example
use google_cloud_discoveryengine_v1::model::answer_query_request::AnswerGenerationSpec;
let x = AnswerQueryRequest::new().set_or_clear_answer_generation_spec(Some(AnswerGenerationSpec::default()/* use setters */));
let x = AnswerQueryRequest::new().set_or_clear_answer_generation_spec(None::<AnswerGenerationSpec>);Sourcepub fn set_search_spec<T>(self, v: T) -> Selfwhere
T: Into<SearchSpec>,
pub fn set_search_spec<T>(self, v: T) -> Selfwhere
T: Into<SearchSpec>,
Sets the value of search_spec.
Example
use google_cloud_discoveryengine_v1::model::answer_query_request::SearchSpec;
let x = AnswerQueryRequest::new().set_search_spec(SearchSpec::default()/* use setters */);Sourcepub fn set_or_clear_search_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<SearchSpec>,
pub fn set_or_clear_search_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<SearchSpec>,
Sets or clears the value of search_spec.
Example
use google_cloud_discoveryengine_v1::model::answer_query_request::SearchSpec;
let x = AnswerQueryRequest::new().set_or_clear_search_spec(Some(SearchSpec::default()/* use setters */));
let x = AnswerQueryRequest::new().set_or_clear_search_spec(None::<SearchSpec>);Sourcepub fn set_query_understanding_spec<T>(self, v: T) -> Selfwhere
T: Into<QueryUnderstandingSpec>,
pub fn set_query_understanding_spec<T>(self, v: T) -> Selfwhere
T: Into<QueryUnderstandingSpec>,
Sets the value of query_understanding_spec.
Example
use google_cloud_discoveryengine_v1::model::answer_query_request::QueryUnderstandingSpec;
let x = AnswerQueryRequest::new().set_query_understanding_spec(QueryUnderstandingSpec::default()/* use setters */);Sourcepub fn set_or_clear_query_understanding_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<QueryUnderstandingSpec>,
pub fn set_or_clear_query_understanding_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<QueryUnderstandingSpec>,
Sets or clears the value of query_understanding_spec.
Example
use google_cloud_discoveryengine_v1::model::answer_query_request::QueryUnderstandingSpec;
let x = AnswerQueryRequest::new().set_or_clear_query_understanding_spec(Some(QueryUnderstandingSpec::default()/* use setters */));
let x = AnswerQueryRequest::new().set_or_clear_query_understanding_spec(None::<QueryUnderstandingSpec>);Sourcepub fn set_asynchronous_mode<T: Into<bool>>(self, v: T) -> Self
👎Deprecated
pub fn set_asynchronous_mode<T: Into<bool>>(self, v: T) -> Self
Sets the value of asynchronous_mode.
Example
let x = AnswerQueryRequest::new().set_asynchronous_mode(true);Sourcepub fn set_user_pseudo_id<T: Into<String>>(self, v: T) -> Self
pub fn set_user_pseudo_id<T: Into<String>>(self, v: T) -> Self
Sets the value of user_pseudo_id.
Example
let x = AnswerQueryRequest::new().set_user_pseudo_id("example");Sourcepub fn set_user_labels<T, K, V>(self, v: T) -> Self
pub fn set_user_labels<T, K, V>(self, v: T) -> Self
Sets the value of user_labels.
Example
let x = AnswerQueryRequest::new().set_user_labels([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_end_user_spec<T>(self, v: T) -> Selfwhere
T: Into<EndUserSpec>,
pub fn set_end_user_spec<T>(self, v: T) -> Selfwhere
T: Into<EndUserSpec>,
Sets the value of end_user_spec.
Example
use google_cloud_discoveryengine_v1::model::answer_query_request::EndUserSpec;
let x = AnswerQueryRequest::new().set_end_user_spec(EndUserSpec::default()/* use setters */);Sourcepub fn set_or_clear_end_user_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<EndUserSpec>,
pub fn set_or_clear_end_user_spec<T>(self, v: Option<T>) -> Selfwhere
T: Into<EndUserSpec>,
Sets or clears the value of end_user_spec.
Example
use google_cloud_discoveryengine_v1::model::answer_query_request::EndUserSpec;
let x = AnswerQueryRequest::new().set_or_clear_end_user_spec(Some(EndUserSpec::default()/* use setters */));
let x = AnswerQueryRequest::new().set_or_clear_end_user_spec(None::<EndUserSpec>);Trait Implementations
Sourceimpl Clone for AnswerQueryRequest
impl Clone for AnswerQueryRequest
Sourcefn clone(&self) -> AnswerQueryRequest
fn clone(&self) -> AnswerQueryRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AnswerQueryRequest
impl Debug for AnswerQueryRequest
Sourceimpl Default for AnswerQueryRequest
impl Default for AnswerQueryRequest
Sourcefn default() -> AnswerQueryRequest
fn default() -> AnswerQueryRequest
Sourceimpl Message for AnswerQueryRequest
impl Message for AnswerQueryRequest
Sourceimpl PartialEq for AnswerQueryRequest
impl PartialEq for AnswerQueryRequest
impl StructuralPartialEq for AnswerQueryRequest