#[non_exhaustive]pub struct BatchUpdateUserLicensesRequest {
pub parent: String,
pub delete_unassigned_user_licenses: bool,
pub source: Option<Source>,
/* private fields */
}user-license-service only.Expand description
Request message for UserLicenseService.BatchUpdateUserLicenses method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent [UserStore][] resource name, format:
projects/{project}/locations/{location}/userStores/{user_store_id}.
delete_unassigned_user_licenses: boolOptional. If true, if user licenses removed associated license config, the user license will be deleted. By default which is false, the user license will be updated to unassigned state.
source: Option<Source>Required. The source of the input.
Implementations
Sourceimpl BatchUpdateUserLicensesRequest
impl BatchUpdateUserLicensesRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_delete_unassigned_user_licenses<T: Into<bool>>(self, v: T) -> Self
pub fn set_delete_unassigned_user_licenses<T: Into<bool>>(self, v: T) -> Self
Sets the value of delete_unassigned_user_licenses.
Example
let x = BatchUpdateUserLicensesRequest::new().set_delete_unassigned_user_licenses(true);Sourcepub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
Sets the value of source.
Note that all the setters affecting source are mutually
exclusive.
Example
use google_cloud_discoveryengine_v1::model::batch_update_user_licenses_request::InlineSource;
let x = BatchUpdateUserLicensesRequest::new().set_source(Some(
google_cloud_discoveryengine_v1::model::batch_update_user_licenses_request::Source::InlineSource(InlineSource::default().into())));Sourcepub fn inline_source(&self) -> Option<&Box<InlineSource>>
pub fn inline_source(&self) -> Option<&Box<InlineSource>>
The value of source
if it holds a InlineSource, None if the field is not set or
holds a different branch.
Sourcepub fn set_inline_source<T: Into<Box<InlineSource>>>(self, v: T) -> Self
pub fn set_inline_source<T: Into<Box<InlineSource>>>(self, v: T) -> Self
Sets the value of source
to hold a InlineSource.
Note that all the setters affecting source are
mutually exclusive.
Example
use google_cloud_discoveryengine_v1::model::batch_update_user_licenses_request::InlineSource;
let x = BatchUpdateUserLicensesRequest::new().set_inline_source(InlineSource::default()/* use setters */);
assert!(x.inline_source().is_some());Trait Implementations
Sourceimpl Clone for BatchUpdateUserLicensesRequest
impl Clone for BatchUpdateUserLicensesRequest
Sourcefn clone(&self) -> BatchUpdateUserLicensesRequest
fn clone(&self) -> BatchUpdateUserLicensesRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for BatchUpdateUserLicensesRequest
impl Default for BatchUpdateUserLicensesRequest
Sourcefn default() -> BatchUpdateUserLicensesRequest
fn default() -> BatchUpdateUserLicensesRequest
impl StructuralPartialEq for BatchUpdateUserLicensesRequest