#[non_exhaustive]pub struct CloudSqlSource {
pub project_id: String,
pub instance_id: String,
pub database_id: String,
pub table_id: String,
pub gcs_staging_dir: String,
pub offload: bool,
/* private fields */
}document-service only.Expand description
Cloud SQL source import data from.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.project_id: StringThe project ID that contains the Cloud SQL source. Has a length limit of 128 characters. If not specified, inherits the project ID from the parent request.
instance_id: StringRequired. The Cloud SQL instance to copy the data from with a length limit of 256 characters.
database_id: StringRequired. The Cloud SQL database to copy the data from with a length limit of 256 characters.
table_id: StringRequired. The Cloud SQL table to copy the data from with a length limit of 256 characters.
gcs_staging_dir: StringIntermediate Cloud Storage directory used for the import with a length limit of 2,000 characters. Can be specified if one wants to have the Cloud SQL export to a specific Cloud Storage directory.
Ensure that the Cloud SQL service account has the necessary Cloud Storage Admin permissions to access the specified Cloud Storage directory.
offload: boolOption for serverless export. Enabling this option will incur additional cost. More info can be found here.
Implementations
Sourceimpl CloudSqlSource
impl CloudSqlSource
Sourcepub fn set_project_id<T: Into<String>>(self, v: T) -> Self
pub fn set_project_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_instance_id<T: Into<String>>(self, v: T) -> Self
pub fn set_instance_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_database_id<T: Into<String>>(self, v: T) -> Self
pub fn set_database_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_table_id<T: Into<String>>(self, v: T) -> Self
pub fn set_table_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_gcs_staging_dir<T: Into<String>>(self, v: T) -> Self
pub fn set_gcs_staging_dir<T: Into<String>>(self, v: T) -> Self
Sets the value of gcs_staging_dir.
Example
let x = CloudSqlSource::new().set_gcs_staging_dir("example");Trait Implementations
Sourceimpl Clone for CloudSqlSource
impl Clone for CloudSqlSource
Sourcefn clone(&self) -> CloudSqlSource
fn clone(&self) -> CloudSqlSource
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CloudSqlSource
impl Debug for CloudSqlSource
Sourceimpl Default for CloudSqlSource
impl Default for CloudSqlSource
Sourcefn default() -> CloudSqlSource
fn default() -> CloudSqlSource
Sourceimpl Message for CloudSqlSource
impl Message for CloudSqlSource
Sourceimpl PartialEq for CloudSqlSource
impl PartialEq for CloudSqlSource
impl StructuralPartialEq for CloudSqlSource