#[non_exhaustive]pub struct CmekConfig {
pub name: String,
pub kms_key: String,
pub kms_key_version: String,
pub state: State,
pub is_default: bool,
pub last_rotation_timestamp_micros: i64,
pub single_region_keys: Vec<SingleRegionKey>,
pub notebooklm_state: NotebookLMState,
/* private fields */
}cmek-config-service or data-store-service or identity-mapping-store-service only.Expand description
Configurations used to enable CMEK data encryption with Cloud KMS keys.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of the CmekConfig of the form
projects/{project}/locations/{location}/cmekConfig or
projects/{project}/locations/{location}/cmekConfigs/{cmek_config}.
kms_key: StringKMS key resource name which will be used to encrypt resources
projects/{project}/locations/{location}/keyRings/{keyRing}/cryptoKeys/{keyId}.
kms_key_version: StringKMS key version resource name which will be used to encrypt resources
<kms_key>/cryptoKeyVersions/{keyVersion}.
state: StateOutput only. The states of the CmekConfig.
is_default: boolOutput only. The default CmekConfig for the Customer.
last_rotation_timestamp_micros: i64Output only. The timestamp of the last key rotation.
single_region_keys: Vec<SingleRegionKey>Optional. Single-regional CMEKs that are required for some VAIS features.
notebooklm_state: NotebookLMStateOutput only. Whether the NotebookLM Corpus is ready to be used.
Implementations
Sourceimpl CmekConfig
impl CmekConfig
Sourcepub fn set_kms_key<T: Into<String>>(self, v: T) -> Self
pub fn set_kms_key<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_kms_key_version<T: Into<String>>(self, v: T) -> Self
pub fn set_kms_key_version<T: Into<String>>(self, v: T) -> Self
Sets the value of kms_key_version.
Example
let x = CmekConfig::new().set_kms_key_version("example");Sourcepub fn set_is_default<T: Into<bool>>(self, v: T) -> Self
pub fn set_is_default<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_last_rotation_timestamp_micros<T: Into<i64>>(self, v: T) -> Self
pub fn set_last_rotation_timestamp_micros<T: Into<i64>>(self, v: T) -> Self
Sets the value of last_rotation_timestamp_micros.
Example
let x = CmekConfig::new().set_last_rotation_timestamp_micros(42);Sourcepub fn set_single_region_keys<T, V>(self, v: T) -> Self
pub fn set_single_region_keys<T, V>(self, v: T) -> Self
Sets the value of single_region_keys.
Example
use google_cloud_discoveryengine_v1::model::SingleRegionKey;
let x = CmekConfig::new()
.set_single_region_keys([
SingleRegionKey::default()/* use setters */,
SingleRegionKey::default()/* use (different) setters */,
]);Sourcepub fn set_notebooklm_state<T: Into<NotebookLMState>>(self, v: T) -> Self
pub fn set_notebooklm_state<T: Into<NotebookLMState>>(self, v: T) -> Self
Sets the value of notebooklm_state.
Example
use google_cloud_discoveryengine_v1::model::cmek_config::NotebookLMState;
let x0 = CmekConfig::new().set_notebooklm_state(NotebookLMState::NotebookLmNotReady);
let x1 = CmekConfig::new().set_notebooklm_state(NotebookLMState::NotebookLmReady);
let x2 = CmekConfig::new().set_notebooklm_state(NotebookLMState::NotebookLmNotEnabled);Trait Implementations
Sourceimpl Clone for CmekConfig
impl Clone for CmekConfig
Sourcefn clone(&self) -> CmekConfig
fn clone(&self) -> CmekConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CmekConfig
impl Debug for CmekConfig
Sourceimpl Default for CmekConfig
impl Default for CmekConfig
Sourcefn default() -> CmekConfig
fn default() -> CmekConfig
Sourceimpl PartialEq for CmekConfig
impl PartialEq for CmekConfig
impl StructuralPartialEq for CmekConfig