#[non_exhaustive]pub struct CreateIdentityMappingStoreRequest {
pub parent: String,
pub identity_mapping_store_id: String,
pub identity_mapping_store: Option<IdentityMappingStore>,
pub cmek_options: Option<CmekOptions>,
/* private fields */
}identity-mapping-store-service only.Expand description
Request message for IdentityMappingStoreService.CreateIdentityMappingStore
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent collection resource name, such as
projects/{project}/locations/{location}.
identity_mapping_store_id: StringRequired. The ID of the Identity Mapping Store to create.
The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), and hyphens (-). The maximum length is 63 characters.
identity_mapping_store: Option<IdentityMappingStore>Required. The Identity Mapping Store to create.
cmek_options: Option<CmekOptions>CMEK options for the Identity Mapping Store. Setting this field will override the default CmekConfig if one is set for the project.
Implementations
Sourceimpl CreateIdentityMappingStoreRequest
impl CreateIdentityMappingStoreRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_identity_mapping_store_id<T: Into<String>>(self, v: T) -> Self
pub fn set_identity_mapping_store_id<T: Into<String>>(self, v: T) -> Self
Sets the value of identity_mapping_store_id.
Example
let x = CreateIdentityMappingStoreRequest::new().set_identity_mapping_store_id("example");Sourcepub fn set_identity_mapping_store<T>(self, v: T) -> Selfwhere
T: Into<IdentityMappingStore>,
pub fn set_identity_mapping_store<T>(self, v: T) -> Selfwhere
T: Into<IdentityMappingStore>,
Sets the value of identity_mapping_store.
Example
use google_cloud_discoveryengine_v1::model::IdentityMappingStore;
let x = CreateIdentityMappingStoreRequest::new().set_identity_mapping_store(IdentityMappingStore::default()/* use setters */);Sourcepub fn set_or_clear_identity_mapping_store<T>(self, v: Option<T>) -> Selfwhere
T: Into<IdentityMappingStore>,
pub fn set_or_clear_identity_mapping_store<T>(self, v: Option<T>) -> Selfwhere
T: Into<IdentityMappingStore>,
Sets or clears the value of identity_mapping_store.
Example
use google_cloud_discoveryengine_v1::model::IdentityMappingStore;
let x = CreateIdentityMappingStoreRequest::new().set_or_clear_identity_mapping_store(Some(IdentityMappingStore::default()/* use setters */));
let x = CreateIdentityMappingStoreRequest::new().set_or_clear_identity_mapping_store(None::<IdentityMappingStore>);Sourcepub fn set_cmek_options<T: Into<Option<CmekOptions>>>(self, v: T) -> Self
pub fn set_cmek_options<T: Into<Option<CmekOptions>>>(self, v: T) -> Self
Sets the value of cmek_options.
Note that all the setters affecting cmek_options are mutually
exclusive.
Example
use google_cloud_discoveryengine_v1::model::create_identity_mapping_store_request::CmekOptions;
let x = CreateIdentityMappingStoreRequest::new().set_cmek_options(Some(CmekOptions::CmekConfigName("example".to_string())));Sourcepub fn cmek_config_name(&self) -> Option<&String>
pub fn cmek_config_name(&self) -> Option<&String>
The value of cmek_options
if it holds a CmekConfigName, None if the field is not set or
holds a different branch.
Sourcepub fn set_cmek_config_name<T: Into<String>>(self, v: T) -> Self
pub fn set_cmek_config_name<T: Into<String>>(self, v: T) -> Self
Sets the value of cmek_options
to hold a CmekConfigName.
Note that all the setters affecting cmek_options are
mutually exclusive.
Example
let x = CreateIdentityMappingStoreRequest::new().set_cmek_config_name(format!("projects/{project_id}/locations/{location_id}/cmekConfig"));
assert!(x.cmek_config_name().is_some());
assert!(x.disable_cmek().is_none());Sourcepub fn disable_cmek(&self) -> Option<&bool>
pub fn disable_cmek(&self) -> Option<&bool>
The value of cmek_options
if it holds a DisableCmek, None if the field is not set or
holds a different branch.
Sourcepub fn set_disable_cmek<T: Into<bool>>(self, v: T) -> Self
pub fn set_disable_cmek<T: Into<bool>>(self, v: T) -> Self
Sets the value of cmek_options
to hold a DisableCmek.
Note that all the setters affecting cmek_options are
mutually exclusive.
Example
let x = CreateIdentityMappingStoreRequest::new().set_disable_cmek(true);
assert!(x.disable_cmek().is_some());
assert!(x.cmek_config_name().is_none());Trait Implementations
Sourceimpl Clone for CreateIdentityMappingStoreRequest
impl Clone for CreateIdentityMappingStoreRequest
Sourcefn clone(&self) -> CreateIdentityMappingStoreRequest
fn clone(&self) -> CreateIdentityMappingStoreRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for CreateIdentityMappingStoreRequest
impl Default for CreateIdentityMappingStoreRequest
Sourcefn default() -> CreateIdentityMappingStoreRequest
fn default() -> CreateIdentityMappingStoreRequest
impl StructuralPartialEq for CreateIdentityMappingStoreRequest