#[non_exhaustive]pub struct GetDataStoreRequest {
pub name: String,
/* private fields */
}Available on crate feature
data-store-service only.Expand description
Request message for DataStoreService.GetDataStore method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. Full resource name of
DataStore, such as
projects/{project}/locations/{location}/collections/{collection_id}/dataStores/{data_store_id}.
If the caller does not have permission to access the DataStore, regardless of whether or not it exists, a PERMISSION_DENIED error is returned.
If the requested DataStore does not exist, a NOT_FOUND error is returned.
Implementations