#[non_exhaustive]pub struct HealthcareFhirConfig {
pub enable_configurable_schema: bool,
pub enable_static_indexing_for_batch_ingestion: bool,
/* private fields */
}Available on crate feature
data-store-service only.Expand description
Config to data store for HEALTHCARE_FHIR vertical.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enable_configurable_schema: boolWhether to enable configurable schema for HEALTHCARE_FHIR vertical.
If set to true, the predefined healthcare fhir schema can be extended
for more customized searching and filtering.
enable_static_indexing_for_batch_ingestion: boolWhether to enable static indexing for HEALTHCARE_FHIR batch
ingestion.
If set to true, the batch ingestion will be processed in a static
indexing mode which is slower but more capable of handling larger
volume.
Implementations
Sourceimpl HealthcareFhirConfig
impl HealthcareFhirConfig
Sourcepub fn set_enable_configurable_schema<T: Into<bool>>(self, v: T) -> Self
pub fn set_enable_configurable_schema<T: Into<bool>>(self, v: T) -> Self
Sets the value of enable_configurable_schema.
Example
ⓘ
let x = HealthcareFhirConfig::new().set_enable_configurable_schema(true);Sourcepub fn set_enable_static_indexing_for_batch_ingestion<T: Into<bool>>(
self,
v: T,
) -> Self
pub fn set_enable_static_indexing_for_batch_ingestion<T: Into<bool>>( self, v: T, ) -> Self
Sets the value of enable_static_indexing_for_batch_ingestion.
Example
ⓘ
let x = HealthcareFhirConfig::new().set_enable_static_indexing_for_batch_ingestion(true);Trait Implementations
Sourceimpl Clone for HealthcareFhirConfig
impl Clone for HealthcareFhirConfig
Sourcefn clone(&self) -> HealthcareFhirConfig
fn clone(&self) -> HealthcareFhirConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HealthcareFhirConfig
impl Debug for HealthcareFhirConfig
Sourceimpl Default for HealthcareFhirConfig
impl Default for HealthcareFhirConfig
Sourcefn default() -> HealthcareFhirConfig
fn default() -> HealthcareFhirConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for HealthcareFhirConfig
impl Message for HealthcareFhirConfig
Sourceimpl PartialEq for HealthcareFhirConfig
impl PartialEq for HealthcareFhirConfig
impl StructuralPartialEq for HealthcareFhirConfig