#[non_exhaustive]pub struct ListDataStoresRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}data-store-service only.Expand description
Request message for DataStoreService.ListDataStores method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent branch resource name, such as
projects/{project}/locations/{location}/collections/{collection_id}.
If the caller does not have permission to list DataStores under this location, regardless of whether or not this data store exists, a PERMISSION_DENIED error is returned.
page_size: i32Maximum number of DataStores to return. If unspecified, defaults to 10. The maximum allowed value is 50. Values above 50 will be coerced to 50.
If this field is negative, an INVALID_ARGUMENT is returned.
page_token: StringA page token ListDataStoresResponse.next_page_token, received from a previous DataStoreService.ListDataStores call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to DataStoreService.ListDataStores must match the call that provided the page token. Otherwise, an INVALID_ARGUMENT error is returned.
filter: StringFilter by solution type .
For example: filter = 'solution_type:SOLUTION_TYPE_SEARCH'
Implementations
Sourceimpl ListDataStoresRequest
impl ListDataStoresRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListDataStoresRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListDataStoresRequest
impl Clone for ListDataStoresRequest
Sourcefn clone(&self) -> ListDataStoresRequest
fn clone(&self) -> ListDataStoresRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ListDataStoresRequest
impl Debug for ListDataStoresRequest
Sourceimpl Default for ListDataStoresRequest
impl Default for ListDataStoresRequest
Sourcefn default() -> ListDataStoresRequest
fn default() -> ListDataStoresRequest
Sourceimpl Message for ListDataStoresRequest
impl Message for ListDataStoresRequest
Sourceimpl PartialEq for ListDataStoresRequest
impl PartialEq for ListDataStoresRequest
impl StructuralPartialEq for ListDataStoresRequest