#[non_exhaustive]pub struct ListSessionsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
/* private fields */
}conversational-search-service or session-service only.Expand description
Request for ListSessions method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The data store resource name. Format:
projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store_id}
page_size: i32Maximum number of results to return. If unspecified, defaults to 50. Max allowed value is 1000.
page_token: StringA page token, received from a previous ListSessions call.
Provide this to retrieve the subsequent page.
filter: StringA comma-separated list of fields to filter by, in EBNF grammar. The supported fields are:
user_pseudo_idstatedisplay_namestarredis_pinnedlabelscreate_timeupdate_time
Examples: “user_pseudo_id = some_id” “display_name = "some_name"” “starred = true” “is_pinned=true AND (NOT labels:hidden)” “create_time > "1970-01-01T12:00:00Z"”
order_by: StringA comma-separated list of fields to order by, sorted in ascending order. Use “desc” after a field name for descending. Supported fields:
update_timecreate_timesession_nameis_pinned
Example:
- “update_time desc”
- “create_time”
- “is_pinned desc,update_time desc”: list sessions by is_pinned first, then by update_time.
Implementations
Sourceimpl ListSessionsRequest
impl ListSessionsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListSessionsRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self