#[non_exhaustive]pub struct Project {
pub name: String,
pub create_time: Option<Timestamp>,
pub provision_completion_time: Option<Timestamp>,
pub service_terms_map: HashMap<String, ServiceTerms>,
/* private fields */
}project-service only.Expand description
Metadata and configurations for a Google Cloud project in the service.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. Full resource name of the project, for example
projects/{project}.
Note that when making requests, project number and project id are both
acceptable, but the server will always respond in project number.
create_time: Option<Timestamp>Output only. The timestamp when this project is created.
provision_completion_time: Option<Timestamp>Output only. The timestamp when this project is successfully provisioned. Empty value means this project is still provisioning and is not ready for use.
service_terms_map: HashMap<String, ServiceTerms>Output only. A map of terms of services. The key is the id of
ServiceTerms.
Implementations
Sourceimpl Project
impl Project
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Project::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Project::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Project::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_provision_completion_time<T>(self, v: T) -> Self
pub fn set_provision_completion_time<T>(self, v: T) -> Self
Sets the value of provision_completion_time.
Example
use wkt::Timestamp;
let x = Project::new().set_provision_completion_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_provision_completion_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_provision_completion_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of provision_completion_time.
Example
use wkt::Timestamp;
let x = Project::new().set_or_clear_provision_completion_time(Some(Timestamp::default()/* use setters */));
let x = Project::new().set_or_clear_provision_completion_time(None::<Timestamp>);Sourcepub fn set_service_terms_map<T, K, V>(self, v: T) -> Self
pub fn set_service_terms_map<T, K, V>(self, v: T) -> Self
Sets the value of service_terms_map.
Example
use google_cloud_discoveryengine_v1::model::project::ServiceTerms;
let x = Project::new().set_service_terms_map([
("key0", ServiceTerms::default()/* use setters */),
("key1", ServiceTerms::default()/* use (different) setters */),
]);Trait Implementations
impl StructuralPartialEq for Project