#[non_exhaustive]pub struct RecrawlUrisMetadata {
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub invalid_uris: Vec<String>,
pub invalid_uris_count: i32,
pub noindex_uris: Vec<String>,
pub noindex_uris_count: i32,
pub uris_not_matching_target_sites: Vec<String>,
pub uris_not_matching_target_sites_count: i32,
pub valid_uris_count: i32,
pub success_count: i32,
pub pending_count: i32,
pub quota_exceeded_count: i32,
/* private fields */
}site-search-engine-service only.Expand description
Metadata related to the progress of the SiteSearchEngineService.RecrawlUris operation. This will be returned by the google.longrunning.Operation.metadata field.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.create_time: Option<Timestamp>Operation create time.
update_time: Option<Timestamp>Operation last update time. If the operation is done, this is also the finish time.
invalid_uris: Vec<String>Unique URIs in the request that have invalid format. Sample limited to 1000.
invalid_uris_count: i32Total number of unique URIs in the request that have invalid format.
noindex_uris: Vec<String>URIs that have no index meta tag. Sample limited to 1000.
noindex_uris_count: i32Total number of URIs that have no index meta tag.
uris_not_matching_target_sites: Vec<String>Unique URIs in the request that don’t match any TargetSite in the DataStore, only match TargetSites that haven’t been fully indexed, or match a TargetSite with type EXCLUDE. Sample limited to 1000.
uris_not_matching_target_sites_count: i32Total number of URIs that don’t match any TargetSites.
valid_uris_count: i32Total number of unique URIs in the request that are not in invalid_uris.
success_count: i32Total number of URIs that have been crawled so far.
pending_count: i32Total number of URIs that have yet to be crawled.
quota_exceeded_count: i32Total number of URIs that were rejected due to insufficient indexing resources.
Implementations
Sourceimpl RecrawlUrisMetadata
impl RecrawlUrisMetadata
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = RecrawlUrisMetadata::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = RecrawlUrisMetadata::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = RecrawlUrisMetadata::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = RecrawlUrisMetadata::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = RecrawlUrisMetadata::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = RecrawlUrisMetadata::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_invalid_uris<T, V>(self, v: T) -> Self
pub fn set_invalid_uris<T, V>(self, v: T) -> Self
Sets the value of invalid_uris.
Example
let x = RecrawlUrisMetadata::new().set_invalid_uris(["a", "b", "c"]);Sourcepub fn set_invalid_uris_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_invalid_uris_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of invalid_uris_count.
Example
let x = RecrawlUrisMetadata::new().set_invalid_uris_count(42);Sourcepub fn set_noindex_uris<T, V>(self, v: T) -> Self
pub fn set_noindex_uris<T, V>(self, v: T) -> Self
Sets the value of noindex_uris.
Example
let x = RecrawlUrisMetadata::new().set_noindex_uris(["a", "b", "c"]);Sourcepub fn set_noindex_uris_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_noindex_uris_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of noindex_uris_count.
Example
let x = RecrawlUrisMetadata::new().set_noindex_uris_count(42);Sourcepub fn set_uris_not_matching_target_sites<T, V>(self, v: T) -> Self
pub fn set_uris_not_matching_target_sites<T, V>(self, v: T) -> Self
Sets the value of uris_not_matching_target_sites.
Example
let x = RecrawlUrisMetadata::new().set_uris_not_matching_target_sites(["a", "b", "c"]);Sourcepub fn set_uris_not_matching_target_sites_count<T: Into<i32>>(
self,
v: T,
) -> Self
pub fn set_uris_not_matching_target_sites_count<T: Into<i32>>( self, v: T, ) -> Self
Sets the value of uris_not_matching_target_sites_count.
Example
let x = RecrawlUrisMetadata::new().set_uris_not_matching_target_sites_count(42);Sourcepub fn set_valid_uris_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_valid_uris_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of valid_uris_count.
Example
let x = RecrawlUrisMetadata::new().set_valid_uris_count(42);Sourcepub fn set_success_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_success_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of success_count.
Example
let x = RecrawlUrisMetadata::new().set_success_count(42);Sourcepub fn set_pending_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_pending_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of pending_count.
Example
let x = RecrawlUrisMetadata::new().set_pending_count(42);Sourcepub fn set_quota_exceeded_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_quota_exceeded_count<T: Into<i32>>(self, v: T) -> Self
Sets the value of quota_exceeded_count.
Example
let x = RecrawlUrisMetadata::new().set_quota_exceeded_count(42);Trait Implementations
Sourceimpl Clone for RecrawlUrisMetadata
impl Clone for RecrawlUrisMetadata
Sourcefn clone(&self) -> RecrawlUrisMetadata
fn clone(&self) -> RecrawlUrisMetadata
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RecrawlUrisMetadata
impl Debug for RecrawlUrisMetadata
Sourceimpl Default for RecrawlUrisMetadata
impl Default for RecrawlUrisMetadata
Sourcefn default() -> RecrawlUrisMetadata
fn default() -> RecrawlUrisMetadata
Sourceimpl Message for RecrawlUrisMetadata
impl Message for RecrawlUrisMetadata
Sourceimpl PartialEq for RecrawlUrisMetadata
impl PartialEq for RecrawlUrisMetadata
impl StructuralPartialEq for RecrawlUrisMetadata