#[non_exhaustive]pub struct TargetSite {
pub name: String,
pub provided_uri_pattern: String,
pub type: Type,
pub exact_match: bool,
pub generated_uri_pattern: String,
pub root_domain_uri: String,
pub site_verification_info: Option<SiteVerificationInfo>,
pub indexing_status: IndexingStatus,
pub update_time: Option<Timestamp>,
pub failure_reason: Option<FailureReason>,
/* private fields */
}site-search-engine-service only.Expand description
A target site for the SiteSearchEngine.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The fully qualified resource name of the target site.
projects/{project}/locations/{location}/collections/{collection}/dataStores/{data_store}/siteSearchEngine/targetSites/{target_site}
The target_site_id is system-generated.
provided_uri_pattern: StringRequired. Input only. The user provided URI pattern from which the
generated_uri_pattern is generated.
type: TypeThe type of the target site, e.g., whether the site is to be included or excluded.
exact_match: boolImmutable. If set to false, a uri_pattern is generated to include all pages whose address contains the provided_uri_pattern. If set to true, an uri_pattern is generated to try to be an exact match of the provided_uri_pattern or just the specific page if the provided_uri_pattern is a specific one. provided_uri_pattern is always normalized to generate the URI pattern to be used by the search engine.
generated_uri_pattern: StringOutput only. This is system-generated based on the provided_uri_pattern.
root_domain_uri: StringOutput only. Root domain of the provided_uri_pattern.
site_verification_info: Option<SiteVerificationInfo>Output only. Site ownership and validity verification status.
indexing_status: IndexingStatusOutput only. Indexing status.
update_time: Option<Timestamp>Output only. The target site’s last updated time.
failure_reason: Option<FailureReason>Output only. Failure reason.
Implementations
Sourceimpl TargetSite
impl TargetSite
Sourcepub fn set_provided_uri_pattern<T: Into<String>>(self, v: T) -> Self
pub fn set_provided_uri_pattern<T: Into<String>>(self, v: T) -> Self
Sets the value of provided_uri_pattern.
Example
let x = TargetSite::new().set_provided_uri_pattern("example");Sourcepub fn set_exact_match<T: Into<bool>>(self, v: T) -> Self
pub fn set_exact_match<T: Into<bool>>(self, v: T) -> Self
Sourcepub fn set_generated_uri_pattern<T: Into<String>>(self, v: T) -> Self
pub fn set_generated_uri_pattern<T: Into<String>>(self, v: T) -> Self
Sets the value of generated_uri_pattern.
Example
let x = TargetSite::new().set_generated_uri_pattern("example");Sourcepub fn set_root_domain_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_root_domain_uri<T: Into<String>>(self, v: T) -> Self
Sets the value of root_domain_uri.
Example
let x = TargetSite::new().set_root_domain_uri("example");Sourcepub fn set_site_verification_info<T>(self, v: T) -> Selfwhere
T: Into<SiteVerificationInfo>,
pub fn set_site_verification_info<T>(self, v: T) -> Selfwhere
T: Into<SiteVerificationInfo>,
Sets the value of site_verification_info.
Example
use google_cloud_discoveryengine_v1::model::SiteVerificationInfo;
let x = TargetSite::new().set_site_verification_info(SiteVerificationInfo::default()/* use setters */);Sourcepub fn set_or_clear_site_verification_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<SiteVerificationInfo>,
pub fn set_or_clear_site_verification_info<T>(self, v: Option<T>) -> Selfwhere
T: Into<SiteVerificationInfo>,
Sets or clears the value of site_verification_info.
Example
use google_cloud_discoveryengine_v1::model::SiteVerificationInfo;
let x = TargetSite::new().set_or_clear_site_verification_info(Some(SiteVerificationInfo::default()/* use setters */));
let x = TargetSite::new().set_or_clear_site_verification_info(None::<SiteVerificationInfo>);Sourcepub fn set_indexing_status<T: Into<IndexingStatus>>(self, v: T) -> Self
pub fn set_indexing_status<T: Into<IndexingStatus>>(self, v: T) -> Self
Sets the value of indexing_status.
Example
use google_cloud_discoveryengine_v1::model::target_site::IndexingStatus;
let x0 = TargetSite::new().set_indexing_status(IndexingStatus::Pending);
let x1 = TargetSite::new().set_indexing_status(IndexingStatus::Failed);
let x2 = TargetSite::new().set_indexing_status(IndexingStatus::Succeeded);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = TargetSite::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = TargetSite::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = TargetSite::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_failure_reason<T>(self, v: T) -> Selfwhere
T: Into<FailureReason>,
pub fn set_failure_reason<T>(self, v: T) -> Selfwhere
T: Into<FailureReason>,
Sets the value of failure_reason.
Example
use google_cloud_discoveryengine_v1::model::target_site::FailureReason;
let x = TargetSite::new().set_failure_reason(FailureReason::default()/* use setters */);Sourcepub fn set_or_clear_failure_reason<T>(self, v: Option<T>) -> Selfwhere
T: Into<FailureReason>,
pub fn set_or_clear_failure_reason<T>(self, v: Option<T>) -> Selfwhere
T: Into<FailureReason>,
Sets or clears the value of failure_reason.
Example
use google_cloud_discoveryengine_v1::model::target_site::FailureReason;
let x = TargetSite::new().set_or_clear_failure_reason(Some(FailureReason::default()/* use setters */));
let x = TargetSite::new().set_or_clear_failure_reason(None::<FailureReason>);Trait Implementations
Sourceimpl Clone for TargetSite
impl Clone for TargetSite
Sourcefn clone(&self) -> TargetSite
fn clone(&self) -> TargetSite
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TargetSite
impl Debug for TargetSite
Sourceimpl Default for TargetSite
impl Default for TargetSite
Sourcefn default() -> TargetSite
fn default() -> TargetSite
Sourceimpl PartialEq for TargetSite
impl PartialEq for TargetSite
impl StructuralPartialEq for TargetSite