#[non_exhaustive]pub struct UserInfo {
pub user_id: String,
pub user_agent: String,
pub time_zone: String,
/* private fields */
}assistant-service or conversational-search-service or recommendation-service or search-service or serving-config-service or user-event-service only.Expand description
Information of an end user.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user_id: StringHighly recommended for logged-in users. Unique identifier for logged-in user, such as a user name. Don’t set for anonymous users.
Always use a hashed value for this ID.
Don’t set the field to the same fixed ID for different users. This mixes the event history of those users together, which results in degraded model quality.
The field must be a UTF-8 encoded string with a length limit of 128
characters. Otherwise, an INVALID_ARGUMENT error is returned.
user_agent: StringUser agent as included in the HTTP header.
The field must be a UTF-8 encoded string with a length limit of 1,000
characters. Otherwise, an INVALID_ARGUMENT error is returned.
This should not be set when using the client side event reporting with GTM or JavaScript tag in UserEventService.CollectUserEvent or if UserEvent.direct_user_request is set.
time_zone: StringOptional. IANA time zone, e.g. Europe/Budapest.
Implementations