#[non_exhaustive]pub struct FailureReason {
pub failure: Option<Failure>,
/* private fields */
}Available on crate feature
site-search-engine-service only.Expand description
Site search indexing failure reasons.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.failure: Option<Failure>Failure reason.
Implementations
Sourceimpl FailureReason
impl FailureReason
Sourcepub fn set_failure<T: Into<Option<Failure>>>(self, v: T) -> Self
pub fn set_failure<T: Into<Option<Failure>>>(self, v: T) -> Self
Sets the value of failure.
Note that all the setters affecting failure are mutually
exclusive.
Example
ⓘ
use google_cloud_discoveryengine_v1::model::target_site::failure_reason::QuotaFailure;
let x = FailureReason::new().set_failure(Some(
google_cloud_discoveryengine_v1::model::target_site::failure_reason::Failure::QuotaFailure(QuotaFailure::default().into())));Sourcepub fn quota_failure(&self) -> Option<&Box<QuotaFailure>>
pub fn quota_failure(&self) -> Option<&Box<QuotaFailure>>
The value of failure
if it holds a QuotaFailure, None if the field is not set or
holds a different branch.
Sourcepub fn set_quota_failure<T: Into<Box<QuotaFailure>>>(self, v: T) -> Self
pub fn set_quota_failure<T: Into<Box<QuotaFailure>>>(self, v: T) -> Self
Sets the value of failure
to hold a QuotaFailure.
Note that all the setters affecting failure are
mutually exclusive.
Example
ⓘ
use google_cloud_discoveryengine_v1::model::target_site::failure_reason::QuotaFailure;
let x = FailureReason::new().set_quota_failure(QuotaFailure::default()/* use setters */);
assert!(x.quota_failure().is_some());Trait Implementations
Sourceimpl Clone for FailureReason
impl Clone for FailureReason
Sourcefn clone(&self) -> FailureReason
fn clone(&self) -> FailureReason
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FailureReason
impl Debug for FailureReason
Sourceimpl Default for FailureReason
impl Default for FailureReason
Sourcefn default() -> FailureReason
fn default() -> FailureReason
Returns the “default value” for a type. Read more
Sourceimpl Message for FailureReason
impl Message for FailureReason
Sourceimpl PartialEq for FailureReason
impl PartialEq for FailureReason
impl StructuralPartialEq for FailureReason