#[non_exhaustive]pub enum LicenseAssignmentState {
Unspecified,
Assigned,
Unassigned,
NoLicense,
NoLicenseAttemptedLogin,
UnknownValue(UnknownValue),
}user-license-service only.Expand description
License assignment state enumeration.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default value.
Assigned
License assigned to the user.
Unassigned
No license assigned to the user. Deprecated, translated to NO_LICENSE.
NoLicense
No license assigned to the user.
NoLicenseAttemptedLogin
User attempted to login but no license assigned to the user. This state is only used for no user first time login attempt but cannot get license assigned. Users already logged in but cannot get license assigned will be assigned NO_LICENSE state(License could be unassigned by admin).
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using LicenseAssignmentState::value or LicenseAssignmentState::name.
Implementations