The messages and enums that are part of this client library.
Modules
- answer
conversational-search-serviceorsession-service - Defines additional types related to Answer.
- answer_
query_ request conversational-search-service - Defines additional types related to AnswerQueryRequest.
- assist_
answer assistant-serviceorconversational-search-serviceorsession-service - Defines additional types related to AssistAnswer.
- assistant_
content assistant-serviceorconversational-search-serviceorsession-service - Defines additional types related to AssistantContent.
- assistant_
grounded_ content assistant-serviceorconversational-search-serviceorsession-service - Defines additional types related to AssistantGroundedContent.
- batch_
get_ documents_ metadata_ request document-service - Defines additional types related to BatchGetDocumentsMetadataRequest.
- batch_
get_ documents_ metadata_ response document-service - Defines additional types related to BatchGetDocumentsMetadataResponse.
- batch_
update_ user_ licenses_ request user-license-service - Defines additional types related to BatchUpdateUserLicensesRequest.
- big_
query_ source completion-serviceordocument-serviceoruser-event-service - Defines additional types related to BigQuerySource.
- bigtable_
options document-service - Defines additional types related to BigtableOptions.
- check_
grounding_ response grounded-generation-service - Defines additional types related to CheckGroundingResponse.
- chunk
conversational-search-serviceorsearch-service - Defines additional types related to Chunk.
- cmek_
config cmek-config-serviceordata-store-serviceoridentity-mapping-store-service - Defines additional types related to CmekConfig.
- complete_
query_ response completion-service - Defines additional types related to CompleteQueryResponse.
- completion_
suggestion completion-service - Defines additional types related to CompletionSuggestion.
- condition
control-service - Defines additional types related to Condition.
- control
control-service - Defines additional types related to Control.
- conversation
conversational-search-service - Defines additional types related to Conversation.
- conversation_
message conversational-search-service - Defines additional types related to ConversationMessage.
- create_
data_ store_ request data-store-service - Defines additional types related to CreateDataStoreRequest.
- create_
identity_ mapping_ store_ request identity-mapping-store-service - Defines additional types related to CreateIdentityMappingStoreRequest.
- custom_
tuning_ model search-tuning-service - Defines additional types related to CustomTuningModel.
- data_
store data-store-service - Defines additional types related to DataStore.
- document
conversational-search-serviceordocument-serviceorrecommendation-serviceorsearch-service - Defines additional types related to Document.
- document_
info recommendation-serviceoruser-event-service - Defines additional types related to DocumentInfo.
- document_
processing_ config data-store-service - Defines additional types related to DocumentProcessingConfig.
- engine
engine-service - Defines additional types related to Engine.
- fetch_
sitemaps_ request site-search-engine-service - Defines additional types related to FetchSitemapsRequest.
- fetch_
sitemaps_ response site-search-engine-service - Defines additional types related to FetchSitemapsResponse.
- generate_
grounded_ content_ request grounded-generation-service - Defines additional types related to GenerateGroundedContentRequest.
- generate_
grounded_ content_ response grounded-generation-service - Defines additional types related to GenerateGroundedContentResponse.
- grounded_
generation_ content grounded-generation-service - Defines additional types related to GroundedGenerationContent.
- identity_
mapping_ entry identity-mapping-store-service - Defines additional types related to IdentityMappingEntry.
- import_
completion_ suggestions_ request completion-service - Defines additional types related to ImportCompletionSuggestionsRequest.
- import_
documents_ request document-service - Defines additional types related to ImportDocumentsRequest.
- import_
error_ config completion-serviceordocument-serviceorsearch-tuning-serviceoruser-event-service - Defines additional types related to ImportErrorConfig.
- import_
identity_ mappings_ request identity-mapping-store-service - Defines additional types related to ImportIdentityMappingsRequest.
- import_
suggestion_ deny_ list_ entries_ request completion-service - Defines additional types related to ImportSuggestionDenyListEntriesRequest.
- import_
user_ events_ request user-event-service - Defines additional types related to ImportUserEventsRequest.
- interval
assistant-serviceorconversational-search-serviceorsearch-serviceorserving-config-service - Defines additional types related to Interval.
- natural_
language_ query_ understanding_ config data-store-service - Defines additional types related to NaturalLanguageQueryUnderstandingConfig.
- principal
conversational-search-serviceordocument-serviceorrecommendation-serviceorsearch-service - Defines additional types related to Principal.
- project
project-service - Defines additional types related to Project.
- purge_
documents_ request document-service - Defines additional types related to PurgeDocumentsRequest.
- purge_
error_ config document-service - Defines additional types related to PurgeErrorConfig.
- purge_
identity_ mappings_ request identity-mapping-store-service - Defines additional types related to PurgeIdentityMappingsRequest.
- query
assistant-serviceorconversational-search-serviceorsession-service - Defines additional types related to Query.
- recommend_
response recommendation-service - Defines additional types related to RecommendResponse.
- recrawl_
uris_ response site-search-engine-service - Defines additional types related to RecrawlUrisResponse.
- safety_
rating conversational-search-serviceorsession-service - Defines additional types related to SafetyRating.
- schema
data-store-serviceorschema-service - Defines additional types related to Schema.
- search_
request assistant-serviceorconversational-search-serviceorsearch-serviceorserving-config-service - Defines additional types related to SearchRequest.
- search_
response conversational-search-serviceorsearch-service - Defines additional types related to SearchResponse.
- serving_
config serving-config-service - Defines additional types related to ServingConfig.
- session
conversational-search-serviceorsession-service - Defines additional types related to Session.
- site_
verification_ info site-search-engine-service - Defines additional types related to SiteVerificationInfo.
- sitemap
site-search-engine-service - Defines additional types related to Sitemap.
- stream_
assist_ request assistant-service - Defines additional types related to StreamAssistRequest.
- stream_
assist_ response assistant-service - Defines additional types related to StreamAssistResponse.
- suggestion_
deny_ list_ entry completion-service - Defines additional types related to SuggestionDenyListEntry.
- target_
site site-search-engine-service - Defines additional types related to TargetSite.
- train_
custom_ model_ request search-tuning-service - Defines additional types related to TrainCustomModelRequest.
- user_
license user-license-service - Defines additional types related to UserLicense.
- workspace_
config data-store-service - Defines additional types related to WorkspaceConfig.
Structs
- Advanced
Site Search Config data-store-service - Configuration data for advance site search.
- Alloy
DbSource document-service - AlloyDB source import data from.
- Answer
conversational-search-serviceorsession-service - Defines an answer.
- Answer
Query Request conversational-search-service - Request message for ConversationalSearchService.AnswerQuery method.
- Answer
Query Response conversational-search-service - Response message for ConversationalSearchService.AnswerQuery method.
- Assist
Answer assistant-serviceorconversational-search-serviceorsession-service - AssistAnswer resource, main part of [AssistResponse][google.cloud.discoveryengine.v1.AssistResponse].
- Assist
User Metadata assistant-service - User metadata of the request.
- Assistant
assistant-serviceandcmek-config-serviceandcompletion-serviceandcontrol-serviceandconversational-search-serviceanddata-store-serviceanddocument-serviceandengine-serviceandgrounded-generation-serviceandidentity-mapping-store-serviceandproject-serviceandrank-serviceandrecommendation-serviceandschema-serviceandsearch-serviceandsearch-tuning-serviceandserving-config-serviceandsession-serviceandsite-search-engine-serviceanduser-event-serviceanduser-license-service - Discovery Engine Assistant resource.
- Assistant
Content assistant-serviceorconversational-search-serviceorsession-service - Multi-modal content.
- Assistant
Grounded Content assistant-serviceorconversational-search-serviceorsession-service - A piece of content and possibly its grounding information.
- Batch
Create Target Site Metadata site-search-engine-service - Metadata related to the progress of the SiteSearchEngineService.BatchCreateTargetSites operation. This will be returned by the google.longrunning.Operation.metadata field.
- Batch
Create Target Sites Request site-search-engine-service - Request message for SiteSearchEngineService.BatchCreateTargetSites method.
- Batch
Create Target Sites Response site-search-engine-service - Response message for SiteSearchEngineService.BatchCreateTargetSites method.
- Batch
GetDocuments Metadata Request document-service - Request message for DocumentService.BatchGetDocumentsMetadata method.
- Batch
GetDocuments Metadata Response document-service - Response message for DocumentService.BatchGetDocumentsMetadata method.
- Batch
Update User Licenses Metadata user-license-service - Metadata related to the progress of the UserLicenseService.BatchUpdateUserLicenses operation. This will be returned by the google.longrunning.Operation.metadata field.
- Batch
Update User Licenses Request user-license-service - Request message for UserLicenseService.BatchUpdateUserLicenses method.
- Batch
Update User Licenses Response user-license-service - Response message for UserLicenseService.BatchUpdateUserLicenses method.
- Batch
Verify Target Sites Metadata site-search-engine-service - Metadata related to the progress of the SiteSearchEngineService.BatchVerifyTargetSites operation. This will be returned by the google.longrunning.Operation.metadata field.
- Batch
Verify Target Sites Request site-search-engine-service - Request message for SiteSearchEngineService.BatchVerifyTargetSites method.
- Batch
Verify Target Sites Response site-search-engine-service - Response message for SiteSearchEngineService.BatchVerifyTargetSites method.
- BigQuery
Source completion-serviceordocument-serviceoruser-event-service - BigQuery source import data from.
- Bigtable
Options document-service - The Bigtable Options object that contains information to support the import.
- Bigtable
Source document-service - The Cloud Bigtable source for importing data.
- Check
Grounding Request grounded-generation-service - Request message for GroundedGenerationService.CheckGrounding method.
- Check
Grounding Response grounded-generation-service - Response message for the GroundedGenerationService.CheckGrounding method.
- Check
Grounding Spec grounded-generation-service - Specification for the grounding check.
- Chunk
conversational-search-serviceorsearch-service - Chunk captures all raw metadata information of items to be recommended or searched in the chunk mode.
- Cloud
SqlSource document-service - Cloud SQL source import data from.
- Cmek
Config cmek-config-serviceordata-store-serviceoridentity-mapping-store-service - Configurations used to enable CMEK data encryption with Cloud KMS keys.
- Collect
User Event Request user-event-service - Request message for CollectUserEvent method.
- Complete
Query Request completion-service - Request message for CompletionService.CompleteQuery method.
- Complete
Query Response completion-service - Response message for CompletionService.CompleteQuery method.
- Completion
Info recommendation-serviceoruser-event-service - Detailed completion information including completion attribution token and clicked completion info.
- Completion
Suggestion completion-service - Autocomplete suggestions that are imported from Customer.
- Condition
control-service - Defines circumstances to be checked before allowing a behavior
- Control
control-service - Defines a conditioned behavior to employ during serving.
Must be attached to a
ServingConfig to be
considered at serving time. Permitted actions dependent on
SolutionType. - Conversation
conversational-search-service - External conversation proto definition.
- Conversation
Context conversational-search-service - Defines context of the conversation
- Conversation
Message conversational-search-service - Defines a conversation message.
- Converse
Conversation Request conversational-search-service - Request message for ConversationalSearchService.ConverseConversation method.
- Converse
Conversation Response conversational-search-service - Response message for ConversationalSearchService.ConverseConversation method.
- Create
Control Request control-service - Request for CreateControl method.
- Create
Conversation Request conversational-search-service - Request for CreateConversation method.
- Create
Data Store Metadata data-store-service - Metadata related to the progress of the DataStoreService.CreateDataStore operation. This will be returned by the google.longrunning.Operation.metadata field.
- Create
Data Store Request data-store-service - Request for DataStoreService.CreateDataStore method.
- Create
Document Request document-service - Request message for DocumentService.CreateDocument method.
- Create
Engine Metadata engine-service - Metadata related to the progress of the EngineService.CreateEngine operation. This will be returned by the google.longrunning.Operation.metadata field.
- Create
Engine Request engine-service - Request for EngineService.CreateEngine method.
- Create
Identity Mapping Store Request identity-mapping-store-service - Request message for IdentityMappingStoreService.CreateIdentityMappingStore
- Create
Schema Metadata schema-service - Metadata for Create Schema LRO.
- Create
Schema Request schema-service - Request message for SchemaService.CreateSchema method.
- Create
Session Request conversational-search-serviceorsession-service - Request for CreateSession method.
- Create
Sitemap Metadata site-search-engine-service - Metadata related to the progress of the SiteSearchEngineService.CreateSitemap operation. This will be returned by the google.longrunning.Operation.metadata field.
- Create
Sitemap Request site-search-engine-service - Request message for SiteSearchEngineService.CreateSitemap method.
- Create
Target Site Metadata site-search-engine-service - Metadata related to the progress of the SiteSearchEngineService.CreateTargetSite operation. This will be returned by the google.longrunning.Operation.metadata field.
- Create
Target Site Request site-search-engine-service - Request message for SiteSearchEngineService.CreateTargetSite method.
- Custom
Attribute recommendation-serviceoruser-event-service - A custom attribute that is not explicitly modeled in a resource, e.g. UserEvent.
- Custom
Tuning Model search-tuning-service - Metadata that describes a custom tuned model.
- Data
Store data-store-service - DataStore captures global settings and configs at the DataStore level.
- Delete
Cmek Config Metadata cmek-config-service - Metadata related to the progress of the CmekConfigService.DeleteCmekConfig operation. This will be returned by the google.longrunning.Operation.metadata field.
- Delete
Cmek Config Request cmek-config-service - Request message for CmekConfigService.DeleteCmekConfig method.
- Delete
Control Request control-service - Request for DeleteControl method.
- Delete
Conversation Request conversational-search-service - Request for DeleteConversation method.
- Delete
Data Store Metadata data-store-service - Metadata related to the progress of the DataStoreService.DeleteDataStore operation. This will be returned by the google.longrunning.Operation.metadata field.
- Delete
Data Store Request data-store-service - Request message for DataStoreService.DeleteDataStore method.
- Delete
Document Request document-service - Request message for DocumentService.DeleteDocument method.
- Delete
Engine Metadata engine-service - Metadata related to the progress of the EngineService.DeleteEngine operation. This will be returned by the google.longrunning.Operation.metadata field.
- Delete
Engine Request engine-service - Request message for EngineService.DeleteEngine method.
- Delete
Identity Mapping Store Metadata identity-mapping-store-service - Metadata related to the progress of the IdentityMappingStoreService.DeleteIdentityMappingStore operation. This will be returned by the google.longrunning.Operation.metadata field.
- Delete
Identity Mapping Store Request identity-mapping-store-service - Request message for IdentityMappingStoreService.DeleteIdentityMappingStore
- Delete
Schema Metadata schema-service - Metadata for DeleteSchema LRO.
- Delete
Schema Request schema-service - Request message for SchemaService.DeleteSchema method.
- Delete
Session Request conversational-search-serviceorsession-service - Request for DeleteSession method.
- Delete
Sitemap Metadata site-search-engine-service - Metadata related to the progress of the SiteSearchEngineService.DeleteSitemap operation. This will be returned by the google.longrunning.Operation.metadata field.
- Delete
Sitemap Request site-search-engine-service - Request message for SiteSearchEngineService.DeleteSitemap method.
- Delete
Target Site Metadata site-search-engine-service - Metadata related to the progress of the SiteSearchEngineService.DeleteTargetSite operation. This will be returned by the google.longrunning.Operation.metadata field.
- Delete
Target Site Request site-search-engine-service - Request message for SiteSearchEngineService.DeleteTargetSite method.
- Disable
Advanced Site Search Metadata site-search-engine-service - Metadata related to the progress of the SiteSearchEngineService.DisableAdvancedSiteSearch operation. This will be returned by the google.longrunning.Operation.metadata field.
- Disable
Advanced Site Search Request site-search-engine-service - Request message for SiteSearchEngineService.DisableAdvancedSiteSearch method.
- Disable
Advanced Site Search Response site-search-engine-service - Response message for SiteSearchEngineService.DisableAdvancedSiteSearch method.
- Document
conversational-search-serviceordocument-serviceorrecommendation-serviceorsearch-service - Document captures all raw metadata information of items to be recommended or searched.
- Document
Info recommendation-serviceoruser-event-service - Detailed document information associated with a user event.
- Document
Processing Config data-store-service - A singleton resource of DataStore. If it’s empty when DataStore is created and DataStore is set to DataStore.ContentConfig.CONTENT_REQUIRED, the default parser will default to digital parser.
- Double
List conversational-search-serviceorsearch-service - Double list.
- Enable
Advanced Site Search Metadata site-search-engine-service - Metadata related to the progress of the SiteSearchEngineService.EnableAdvancedSiteSearch operation. This will be returned by the google.longrunning.Operation.metadata field.
- Enable
Advanced Site Search Request site-search-engine-service - Request message for SiteSearchEngineService.EnableAdvancedSiteSearch method.
- Enable
Advanced Site Search Response site-search-engine-service - Response message for SiteSearchEngineService.EnableAdvancedSiteSearch method.
- Engine
engine-service - Metadata that describes the training and serving parameters of an Engine.
- Fact
Chunk grounded-generation-service - Fact Chunk.
- Fetch
Domain Verification Status Request site-search-engine-service - Request message for SiteSearchEngineService.FetchDomainVerificationStatus method.
- Fetch
Domain Verification Status Response site-search-engine-service - Response message for SiteSearchEngineService.FetchDomainVerificationStatus method.
- Fetch
Sitemaps Request site-search-engine-service - Request message for SiteSearchEngineService.FetchSitemaps method.
- Fetch
Sitemaps Response site-search-engine-service - Response message for SiteSearchEngineService.FetchSitemaps method.
- Fhir
Store Source document-service - Cloud FhirStore source import data from.
- Firestore
Source document-service - Firestore source import data from.
- GcsSource
completion-serviceordocument-serviceoruser-event-service - Cloud Storage location for input content.
- Generate
Grounded Content Request grounded-generation-service - Top-level message sent by the client for the
GenerateGroundedContentmethod. - Generate
Grounded Content Response grounded-generation-service - Response for the
GenerateGroundedContentmethod. - GetAnswer
Request conversational-search-service - Request for GetAnswer method.
- GetCmek
Config Request cmek-config-service - Request message for GetCmekConfigRequest method.
- GetControl
Request control-service - Request for GetControl method.
- GetConversation
Request conversational-search-service - Request for GetConversation method.
- GetData
Store Request data-store-service - Request message for DataStoreService.GetDataStore method.
- GetDocument
Request document-service - Request message for DocumentService.GetDocument method.
- GetEngine
Request engine-service - Request message for EngineService.GetEngine method.
- GetIdentity
Mapping Store Request identity-mapping-store-service - Request message for IdentityMappingStoreService.GetIdentityMappingStore
- GetSchema
Request schema-service - Request message for SchemaService.GetSchema method.
- GetSession
Request conversational-search-serviceorsession-service - Request for GetSession method.
- GetSite
Search Engine Request site-search-engine-service - Request message for SiteSearchEngineService.GetSiteSearchEngine method.
- GetTarget
Site Request site-search-engine-service - Request message for SiteSearchEngineService.GetTargetSite method.
- Grounded
Generation Content grounded-generation-service - Base structured datatype containing multi-part content of a message.
- Grounding
Fact grounded-generation-service - Grounding Fact.
- Healthcare
Fhir Config data-store-service - Config to data store for
HEALTHCARE_FHIRvertical. - Identity
Mapping Entry identity-mapping-store-service - Identity Mapping Entry that maps an external identity to an internal identity.
- Identity
Mapping Entry Operation Metadata identity-mapping-store-service - IdentityMappingEntry LongRunningOperation metadata for IdentityMappingStoreService.ImportIdentityMappings and IdentityMappingStoreService.PurgeIdentityMappings
- Identity
Mapping Store identity-mapping-store-service - Identity Mapping Store which contains Identity Mapping Entries.
- Import
Completion Suggestions Metadata completion-service - Metadata related to the progress of the ImportCompletionSuggestions operation. This will be returned by the google.longrunning.Operation.metadata field.
- Import
Completion Suggestions Request completion-service - Request message for CompletionService.ImportCompletionSuggestions method.
- Import
Completion Suggestions Response completion-service - Response of the CompletionService.ImportCompletionSuggestions method. If the long running operation is done, this message is returned by the google.longrunning.Operations.response field if the operation is successful.
- Import
Documents Metadata document-service - Metadata related to the progress of the ImportDocuments operation. This is returned by the google.longrunning.Operation.metadata field.
- Import
Documents Request document-service - Request message for Import methods.
- Import
Documents Response document-service - Response of the ImportDocumentsRequest. If the long running operation is done, then this message is returned by the google.longrunning.Operations.response field if the operation was successful.
- Import
Error Config completion-serviceordocument-serviceorsearch-tuning-serviceoruser-event-service - Configuration of destination for Import related errors.
- Import
Identity Mappings Request identity-mapping-store-service - Request message for IdentityMappingStoreService.ImportIdentityMappings
- Import
Identity Mappings Response identity-mapping-store-service - Response message for IdentityMappingStoreService.ImportIdentityMappings
- Import
Suggestion Deny List Entries Metadata completion-service - Metadata related to the progress of the ImportSuggestionDenyListEntries operation. This is returned by the google.longrunning.Operation.metadata field.
- Import
Suggestion Deny List Entries Request completion-service - Request message for CompletionService.ImportSuggestionDenyListEntries method.
- Import
Suggestion Deny List Entries Response completion-service - Response message for CompletionService.ImportSuggestionDenyListEntries method.
- Import
User Events Metadata user-event-service - Metadata related to the progress of the Import operation. This is returned by the google.longrunning.Operation.metadata field.
- Import
User Events Request user-event-service - Request message for the ImportUserEvents request.
- Import
User Events Response user-event-service - Response of the ImportUserEventsRequest. If the long running operation was successful, then this message is returned by the google.longrunning.Operations.response field if the operation was successful.
- Interval
assistant-serviceorconversational-search-serviceorsearch-serviceorserving-config-service - A floating point interval.
- List
Cmek Configs Request cmek-config-service - Request message for CmekConfigService.ListCmekConfigs method.
- List
Cmek Configs Response cmek-config-service - Response message for CmekConfigService.ListCmekConfigs method.
- List
Controls Request control-service - Request for ListControls method.
- List
Controls Response control-service - Response for ListControls method.
- List
Conversations Request conversational-search-service - Request for ListConversations method.
- List
Conversations Response conversational-search-service - Response for ListConversations method.
- List
Custom Models Request search-tuning-service - Request message for SearchTuningService.ListCustomModels method.
- List
Custom Models Response search-tuning-service - Response message for SearchTuningService.ListCustomModels method.
- List
Data Stores Request data-store-service - Request message for DataStoreService.ListDataStores method.
- List
Data Stores Response data-store-service - Response message for DataStoreService.ListDataStores method.
- List
Documents Request document-service - Request message for DocumentService.ListDocuments method.
- List
Documents Response document-service - Response message for DocumentService.ListDocuments method.
- List
Engines Request engine-service - Request message for EngineService.ListEngines method.
- List
Engines Response engine-service - Response message for EngineService.ListEngines method.
- List
Identity Mapping Stores Request identity-mapping-store-service - Request message for IdentityMappingStoreService.ListIdentityMappingStores
- List
Identity Mapping Stores Response identity-mapping-store-service - Response message for IdentityMappingStoreService.ListIdentityMappingStores
- List
Identity Mappings Request identity-mapping-store-service - Request message for IdentityMappingStoreService.ListIdentityMappings
- List
Identity Mappings Response identity-mapping-store-service - Response message for IdentityMappingStoreService.ListIdentityMappings
- List
Schemas Request schema-service - Request message for SchemaService.ListSchemas method.
- List
Schemas Response schema-service - Response message for SchemaService.ListSchemas method.
- List
Sessions Request conversational-search-serviceorsession-service - Request for ListSessions method.
- List
Sessions Response conversational-search-serviceorsession-service - Response for ListSessions method.
- List
Target Sites Request site-search-engine-service - Request message for SiteSearchEngineService.ListTargetSites method.
- List
Target Sites Response site-search-engine-service - Response message for SiteSearchEngineService.ListTargetSites method.
- List
User Licenses Request user-license-service - Request message for UserLicenseService.ListUserLicenses.
- List
User Licenses Response user-license-service - Response message for UserLicenseService.ListUserLicenses.
- Media
Info recommendation-serviceoruser-event-service - Media-specific user event information.
- Natural
Language Query Understanding Config data-store-service - Configuration for Natural Language Query Understanding.
- Page
Info recommendation-serviceoruser-event-service - Detailed page information.
- Panel
Info recommendation-serviceoruser-event-service - Detailed panel information associated with a user event.
- Principal
conversational-search-serviceordocument-serviceorrecommendation-serviceorsearch-service - Principal identifier of a user or a group.
- Project
project-service - Metadata and configurations for a Google Cloud project in the service.
- Provision
Project Metadata project-service - Metadata associated with a project provision operation.
- Provision
Project Request project-service - Request for ProjectService.ProvisionProject method.
- Purge
Completion Suggestions Metadata completion-service - Metadata related to the progress of the PurgeCompletionSuggestions operation. This is returned by the google.longrunning.Operation.metadata field.
- Purge
Completion Suggestions Request completion-service - Request message for CompletionService.PurgeCompletionSuggestions method.
- Purge
Completion Suggestions Response completion-service - Response message for CompletionService.PurgeCompletionSuggestions method.
- Purge
Documents Metadata document-service - Metadata related to the progress of the PurgeDocuments operation. This will be returned by the google.longrunning.Operation.metadata field.
- Purge
Documents Request document-service - Request message for DocumentService.PurgeDocuments method.
- Purge
Documents Response document-service - Response message for DocumentService.PurgeDocuments method. If the long running operation is successfully done, then this message is returned by the google.longrunning.Operations.response field.
- Purge
Error Config document-service - Configuration of destination for Purge related errors.
- Purge
Identity Mappings Request identity-mapping-store-service - Request message for IdentityMappingStoreService.PurgeIdentityMappings
- Purge
Suggestion Deny List Entries Metadata completion-service - Metadata related to the progress of the PurgeSuggestionDenyListEntries operation. This is returned by the google.longrunning.Operation.metadata field.
- Purge
Suggestion Deny List Entries Request completion-service - Request message for CompletionService.PurgeSuggestionDenyListEntries method.
- Purge
Suggestion Deny List Entries Response completion-service - Response message for CompletionService.PurgeSuggestionDenyListEntries method.
- Purge
User Events Metadata user-event-service - Metadata related to the progress of the PurgeUserEvents operation. This will be returned by the google.longrunning.Operation.metadata field.
- Purge
User Events Request user-event-service - Request message for PurgeUserEvents method.
- Purge
User Events Response user-event-service - Response of the PurgeUserEventsRequest. If the long running operation is successfully done, then this message is returned by the google.longrunning.Operations.response field.
- Query
assistant-serviceorconversational-search-serviceorsession-service - Defines a user inputed query.
- Rank
Request rank-service - Request message for RankService.Rank method.
- Rank
Response rank-service - Response message for RankService.Rank method.
- Ranking
Record rank-service - Record message for RankService.Rank method.
- Recommend
Request recommendation-service - Request message for Recommend method.
- Recommend
Response recommendation-service - Response message for Recommend method.
- Recrawl
Uris Metadata site-search-engine-service - Metadata related to the progress of the SiteSearchEngineService.RecrawlUris operation. This will be returned by the google.longrunning.Operation.metadata field.
- Recrawl
Uris Request site-search-engine-service - Request message for SiteSearchEngineService.RecrawlUris method.
- Recrawl
Uris Response site-search-engine-service - Response message for SiteSearchEngineService.RecrawlUris method.
- Reply
conversational-search-service - Defines a reply message to user.
- Safety
Rating conversational-search-serviceorsession-service - Safety rating corresponding to the generated content.
- Schema
data-store-serviceorschema-service - Defines the structure and layout of a type of document data.
- Search
Info recommendation-serviceoruser-event-service - Detailed search information.
- Search
Link Promotion control-serviceorconversational-search-serviceorsearch-service - Promotion proto includes uri and other helping information to display the promotion.
- Search
Request assistant-serviceorconversational-search-serviceorsearch-serviceorserving-config-service - Request message for SearchService.Search method.
- Search
Response conversational-search-serviceorsearch-service - Response message for SearchService.Search method.
- Serving
Config serving-config-service - Configures metadata that is used to generate serving time results (e.g. search results or recommendation predictions). The ServingConfig is passed in the search and predict request and generates results.
- Session
conversational-search-serviceorsession-service - External session proto definition.
- Single
Region Key cmek-config-serviceordata-store-serviceoridentity-mapping-store-service - Metadata for single-regional CMEKs.
- Site
Search Engine site-search-engine-service - SiteSearchEngine captures DataStore level site search persisting configurations. It is a singleton value per data store.
- Site
Verification Info site-search-engine-service - Verification information for target sites in advanced site search.
- Sitemap
site-search-engine-service - A sitemap for the SiteSearchEngine.
- Spanner
Source document-service - The Spanner source for importing data
- Stream
Assist Request assistant-service - Request for the [AssistantService.StreamAssist][google.cloud.discoveryengine.v1.AssistantService.StreamAssist] method.
- Stream
Assist Response assistant-service - Response for the [AssistantService.StreamAssist][google.cloud.discoveryengine.v1.AssistantService.StreamAssist] method.
- Suggestion
Deny List Entry completion-service - Suggestion deny list entry identifying the phrase to block from suggestions and the applied operation for the phrase.
- Target
Site site-search-engine-service - A target site for the SiteSearchEngine.
- Text
Input conversational-search-service - Defines text input.
- Train
Custom Model Metadata search-tuning-service - Metadata related to the progress of the TrainCustomModel operation. This is returned by the google.longrunning.Operation.metadata field.
- Train
Custom Model Request search-tuning-service - Request message for SearchTuningService.TrainCustomModel method.
- Train
Custom Model Response search-tuning-service - Response of the TrainCustomModelRequest. This message is returned by the google.longrunning.Operations.response field.
- Transaction
Info recommendation-serviceoruser-event-service - A transaction represents the entire purchase transaction.
- Update
Cmek Config Metadata cmek-config-service - Metadata related to the progress of the CmekConfigService.UpdateCmekConfig operation. This will be returned by the google.longrunning.Operation.metadata field.
- Update
Cmek Config Request cmek-config-service - Request message for UpdateCmekConfig method. rpc.
- Update
Control Request control-service - Request for UpdateControl method.
- Update
Conversation Request conversational-search-service - Request for UpdateConversation method.
- Update
Data Store Request data-store-service - Request message for DataStoreService.UpdateDataStore method.
- Update
Document Request document-service - Request message for DocumentService.UpdateDocument method.
- Update
Engine Request engine-service - Request message for EngineService.UpdateEngine method.
- Update
Schema Metadata schema-service - Metadata for UpdateSchema LRO.
- Update
Schema Request schema-service - Request message for SchemaService.UpdateSchema method.
- Update
Serving Config Request serving-config-service - Request for UpdateServingConfig method.
- Update
Session Request conversational-search-serviceorsession-service - Request for UpdateSession method.
- Update
Target Site Metadata site-search-engine-service - Metadata related to the progress of the SiteSearchEngineService.UpdateTargetSite operation. This will be returned by the google.longrunning.Operation.metadata field.
- Update
Target Site Request site-search-engine-service - Request message for SiteSearchEngineService.UpdateTargetSite method.
- User
Event recommendation-serviceoruser-event-service - UserEvent captures all metadata information Discovery Engine API needs to know about how end users interact with your website.
- User
Info assistant-serviceorconversational-search-serviceorrecommendation-serviceorsearch-serviceorserving-config-serviceoruser-event-service - Information of an end user.
- User
License user-license-service - User License information assigned by the admin.
- Workspace
Config data-store-service - Config to store data store type configuration for workspace data
- Write
User Event Request user-event-service - Request message for WriteUserEvent method.
Enums
- Harm
Category conversational-search-serviceorsession-service - Harm categories that will block the content.
- Industry
Vertical data-store-serviceorengine-service - The industry vertical associated with the DataStore.
- Search
AddOn engine-service - Add-on that provides additional functionality for search.
- Search
Tier engine-service - Tiers of search features. Different tiers might have different pricing. To learn more, check the pricing documentation.
- Search
UseCase control-service - Defines a further subdivision of
SolutionType. Specifically applies to SOLUTION_TYPE_SEARCH. - Solution
Type control-serviceordata-store-serviceorengine-serviceorserving-config-service - The type of solution.